@@ -1,6 +1,6 @@
 /*
 
- $Id: arch.cpp,v 1.40 2002/01/21 06:31:41 waba Exp $
+ $Id: arch.cpp,v 1.40.2.2 2002/04/30 11:15:34 helio Exp $
 
  ark -- archiver for the KDE project
 
@@ -204,7 +204,7 @@ void Arch::slotExtractExited(KProcess *_kp)
 	{
 	  QApplication::restoreOverrideCursor();
 	  int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
-		i18n("Sorry, the extract operation failed.\n"
+		i18n("The extract operation failed.\n"
 		     "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
@@ -247,7 +247,7 @@ void Arch::slotAddExited(KProcess *_kp)
     {
       QApplication::restoreOverrideCursor();
       int ret = KMessageBox::warningYesNo(m_gui->getArkWidget(),
-		 i18n("Sorry, the add operation failed.\n"
+		 i18n("The add operation failed.\n"
 		      "Do you wish to view the shell output?"), i18n("Error"));
 	  if (ret == KMessageBox::Yes)
 	    m_gui->viewShellOutput();
