@@ -1,6 +1,6 @@
 /*
 
- $Id: arksettings.cpp,v 1.28 2001/06/11 14:52:39 maragato Exp $
+ $Id: arksettings.cpp,v 1.29 2001/10/11 02:28:34 mueller Exp $
 
  ark -- archiver for the KDE project
 
@@ -32,10 +32,8 @@
 #include <stdlib.h>	// for getenv
 
 // QT includes
-#include <qstring.h>
 
 // KDE includes
-#include <kapp.h>
 #include <kglobal.h>
 #include <kdebug.h>
 #include <klocale.h>
