@@ -1,6 +1,6 @@
 /*
 
-  $Id: filelistview.cpp,v 1.26 2002/03/05 08:30:13 mlaurent Exp $
+  $Id: filelistview.cpp,v 1.26.2.2 2002/04/30 11:15:34 helio Exp $
 
   ark -- archiver for the KDE project
 
@@ -38,6 +38,7 @@
 // KDE includes
 #include <klocale.h>
 #include <kdebug.h>
+#include <kglobalsettings.h>
 
 #include "filelistview.h"
 #include "arch.h"
@@ -80,12 +81,12 @@ QString FileLVI::key(int column, bool ascending) const
     if ( columnName == SIZE_STRING ||
 	 columnName == PACKED_STRING )
       {
-	s.sprintf("%.10ld", text(column).toInt());
+	s.sprintf("%.10ld", (long)(text(column).toInt()));
 	return s;
       }
     else if (columnName == RATIO_STRING)
       {
-	s.sprintf("%.10ld", text(column).toInt());
+	s.sprintf("%.10ld", (long)(text(column).toInt()));
 	return s;
       }
 		else if(0 == column)
@@ -183,34 +184,45 @@ bool FileListView::isSelectionEmpty()
 	return true;
 }
 
-void FileListView::contentsMousePressEvent(QMouseEvent *e)
+void 
+FileListView::contentsMousePressEvent(QMouseEvent *e)
 {
-	m_bPressed = true;
+	if(e->button()==QMouseEvent::LeftButton)
+	{
+		m_bPressed = true;
+		presspos = e->pos();
+	}
+	
 	KListView::contentsMousePressEvent(e);
 }
 
-void FileListView::contentsMouseReleaseEvent(QMouseEvent *e)
+void 
+FileListView::contentsMouseReleaseEvent(QMouseEvent *e)
 {
 	m_bPressed = false;
 	KListView::contentsMouseReleaseEvent(e);
 }
 
-void FileListView::contentsMouseMoveEvent(QMouseEvent *e)
+void 
+FileListView::contentsMouseMoveEvent(QMouseEvent *e)
 {
 	if(!m_bPressed)
 	{
 		KListView::contentsMouseMoveEvent(e);
 	}
-	else
+	else if( ( presspos - e->pos() ).manhattanLength() > KGlobalSettings::dndEventDelay() )
 	{
 		m_bPressed = false;	// Prevent triggering again
 		if(isSelectionEmpty())
+		{
 			return;
+		}
 		QStringList *dragFiles = selectedFilenames();
 		m_pParent->setDragInProgress(true);
 		m_pParent->storeDragNames(*dragFiles);
 		kdDebug(1601) << "Drag Starting..." << endl;
 		m_pParent->prepareViewFiles(dragFiles);
+		KListView::contentsMouseMoveEvent(e);
 	}
 }
 
