@@ -1,6 +1,6 @@
 /*
 
- $Id: selectDlg.h,v 1.4 2000/01/10 20:54:41 ezust Exp $
+ $Id: selectDlg.h,v 1.5 2001/02/23 18:46:10 mjarrett Exp $
 
  ark -- archiver for the KDE project
 
@@ -28,19 +28,19 @@
 #ifndef SELECT_DLG_H
 #define SELECT_DLG_H
 
-// Qt includes
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <qpushbutton.h>
-#include <qstring.h>
+class QWidget;
+class QString;
+class QDialog;
+class QLineEdit;
+class QPushButton;
+
+class ArkSettings;
 
-// ark includes
-#include <arksettings.h>
 
 class SelectDlg : public QDialog {
 	Q_OBJECT
 public:
-	SelectDlg(  ArkSettings *d, QWidget *parent=0, const char *name=0 );
+	SelectDlg(ArkSettings *d, QWidget *parent=0, const char *name=0);
 	QString getRegExp() const;
 
 
