@@ -1,6 +1,6 @@
 /*
 
- $Id: shellOutputDlg.cpp,v 1.6 2001/01/08 16:14:51 mlaurent Exp $
+ $Id: shellOutputDlg.cpp,v 1.9 2001/10/11 02:28:34 mueller Exp $
 
  ark -- archiver for the KDE project
 
@@ -27,15 +27,9 @@
 
 // Qt includes
 #include <qpushbutton.h>
-#include <qmultilineedit.h>
-#include <qgrid.h>
 #include <qlayout.h>
 
-#include <kdebug.h>
 #include <klocale.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kcharsets.h>
 
 // ark includes
 #include "shellOutputDlg.h"
@@ -52,11 +46,6 @@ ShellOutputDlg::ShellOutputDlg( ArkSettings *_data, QWidget *_parent,
   l1->setReadOnly( true );
   grid1->addMultiCellWidget(l1,0,8,0,4);
 
-  QFont my_font = KGlobalSettings::generalFont();
-  KGlobal::charsets()->setQFont(my_font, KGlobal::locale()->charset());
-
-  l1->setFont( my_font );
-
   l1->setText( *(_data->getLastShellOutput()) );
   l1->setCursorPosition(l1->numLines(), 0);
 
