@@ -1,5 +1,5 @@
 /*
-    $Id: kcalctype.h,v 1.6 1998/04/16 19:34:19 wuebben Exp $
+    $Id: kcalctype.h,v 1.15 2002/02/24 11:20:22 hausmann Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -24,21 +24,23 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+	#include "../config.h"
 #endif
 
 #ifndef KCALC_TYPE_H
 #define KCALC_TYPE_H
 
+#include <math.h>
+
 // The following for all the poor devels out there who don't have long double math.
 // I guess it's time to switch to LINUX guys .....
 
 // Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
 // glibc
 
-#ifdef HAVE_LONG_DOUBLE
-#undef HAVE_LONG_DOUBLE
-#endif
+//#ifdef HAVE_LONG_DOUBLE
+//#undef HAVE_LONG_DOUBLE
+//#endif
 
 #ifdef HAVE_LONG_DOUBLE
 
@@ -49,55 +51,57 @@
 
 
 
-#define CALCAMNT        long double
+	typedef long double CALCAMNT;
 #else
-#define CALCAMNT        double
+	typedef double CALCAMNT;
 #endif
 
 
+
 #ifdef HAVE_LONG_DOUBLE
-#define FABS(X)   	fabsl(X)
-#define MODF(X,Y)       modfl(X,Y)
-#define FMOD(X,Y)   	fmodl(X,Y)
-#define SIN(X)		sinl(X)
-#define ASIN(X)		asinl(X)
-#define SINH(X)		sinhl(X)
-#define ASINH(X)	asinhl(X)
-#define COS(X)		cosl(X)
-#define COSH(X)		coshl(X)
-#define ACOS(X)		acosl(X)
-#define ACOSH(X)	acoshl(X)
-#define TAN(X)		tanl(X)
-#define TANH(X)		tanhl(X)
-#define ATAN(X)		atanl(X)
-#define ATANH(X)	atanhl(X)
-#define EXP(X)		expl(X)
-#define POW(X,Y)	powl(X,Y)
-#define LOG(X)		logl(X)
-#define LOG_TEN(X)	log10l(X)
-#define SQRT(X)		sqrtl(X)
+	#define FABS(X)		fabsl(X)
+	#define MODF(X,Y)	modfl(X,Y)
+	#define FMOD(X,Y)	fmodl(X,Y)
+	#define SIN(X)		sinl(X)
+	#define ASIN(X)		asinl(X)
+	#define SINH(X)		sinhl(X)
+	#define ASINH(X)	asinhl(X)
+	#define COS(X)		cosl(X)
+	#define COSH(X)		coshl(X)
+	#define ACOS(X)		acosl(X)
+	#define ACOSH(X)	acoshl(X)
+	#define TAN(X)		tanl(X)
+	#define TANH(X)		tanhl(X)
+	#define ATAN(X)		atanl(X)
+	#define ATANH(X)	atanhl(X)
+	#define EXP(X)		expl(X)
+	#define POW(X,Y)	powl(X,Y)
+	#define LOG(X)		logl(X)
+	#define LOG_TEN(X)	log10l(X)
+	#define SQRT(X)		sqrtl(X)
+	#define ISINF(X)	isinfl(X)
 #else
-#define FABS(X)		fabs(X)
-#define MODF(X,Y)    	modf(X,Y)
-#define FMOD(X,Y)   	fmod(X,Y)
-#define SIN(X)		sin(X)
-#define ASIN(X)		asin(X)
-#define SINH(X)		sinh(X)
-#define ASINH(X)	asinh(X)
-#define COS(X)		cos(X)
-#define COSH(X)		cosh(X)
-#define ACOS(X)		acos(X)
-#define ACOSH(X)	acosh(X)
-#define TAN(X)		tan(X)
-#define TANH(X)		tanh(X)
-#define ATAN(X)		atan(X)
-#define ATANH(X)	atanh(X)
-#define EXP(X)		exp(X)
-#define POW(X,Y)	pow(X,Y)
-#define LOG(X)		log(X)
-#define LOG_TEN(X)	log10(X)
-#define SQRT(X)		sqrt(X)
+	#define FABS(X)		fabs(X)
+	#define MODF(X,Y)	modf(X,Y)
+	#define FMOD(X,Y)	fmod(X,Y)
+	#define SIN(X)		sin(X)
+	#define ASIN(X)		asin(X)
+	#define SINH(X)		sinh(X)
+	#define ASINH(X)	asinh(X)
+	#define COS(X)		cos(X)
+	#define COSH(X)		cosh(X)
+	#define ACOS(X)		acos(X)
+	#define ACOSH(X)	acosh(X)
+	#define TAN(X)		tan(X)
+	#define TANH(X)		tanh(X)
+	#define ATAN(X)		atan(X)
+	#define ATANH(X)	atanh(X)
+	#define EXP(X)		exp(X)
+	#define POW(X,Y)	pow(X,Y)
+	#define LOG(X)		log(X)
+	#define LOG_TEN(X)	log10(X)
+	#define SQRT(X)		sqrt(X)
+	#define ISINF(X)	isinf(X)
 #endif
 
-
 #endif 
