@@ -1,15 +1,13 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: passwddlg.cpp,v 1.2 2000/07/05 17:28:14 jansen Exp $
+ * $Id: passwddlg.cpp,v 1.4 2002/01/04 21:18:49 binner Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
  */
 
-#include <qstring.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
 
 #include "passwd.h"
 #include "passwddlg.h"
@@ -20,7 +18,7 @@ KDEpasswd1Dialog::KDEpasswd1Dialog(QCString user)
 {
     m_User = user;
 
-    setCaption(i18n("Change password"));
+    setCaption(i18n("Change Password"));
     setPrompt(i18n("Please enter your current password."));
 }
 
@@ -80,7 +78,7 @@ KDEpasswd2Dialog::KDEpasswd2Dialog(const char *oldpass, QCString user)
     m_Pass = oldpass;
     m_User = user;
 
-    setCaption(i18n("Change password"));
+    setCaption(i18n("Change Password"));
     setPrompt(i18n("Please enter your new password."));
 }
 
