@@ -1,6 +1,6 @@
-   /*
+  /*
 
-    $Id: kedit.cpp,v 1.136 2001/01/21 07:22:58 waba Exp $
+    $Id: kedit.cpp,v 1.157 2002/02/26 16:08:29 coolo Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -25,56 +25,45 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-//
+#include <unistd.h>
 
 #include <qdragobject.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qtabdialog.h>
-#include <qtextstream.h>
 #include <qtimer.h>
-#include <qcolor.h>
 
-#include <kapp.h>
-#include <kcolordlg.h>
+#include <kapplication.h>
 #include <kcursor.h>
-#include <kfiledialog.h>
-#include <kiconloader.h>
-#include <kio/job.h>
+#include "ktextfiledlg.h"
 #include <kio/netaccess.h>
-#include <kglobal.h>
-#include <klocale.h>
 #include <kmessagebox.h>
-#include <ksavefile.h>
 #include <ktempfile.h>
-#include <kstdaccel.h>
-#include <kspell.h>
-#include <ksconfig.h>
-#include <keditcl.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kedittoolbar.h>
 #include <kkeydialog.h>
+#include <klocale.h>
+
+#include <qpainter.h>
+#include <qpen.h>
+#include <qpaintdevicemetrics.h>
+#include <qsimplerichtext.h>
+#include <kprinter.h>
 
 #include "kedit.h"
 #include "mail.h"
 #include "optiondialog.h"
-#include "urldlg.h"
 #include "version.h"
 
-#include <kaction.h>
-#include <kstdaction.h>
 #include <kdebug.h>
 
 #include <stdlib.h>
+#include <kstatusbar.h>
 
-QList<TopLevel> *TopLevel::windowList = 0;
+QPtrList<TopLevel> *TopLevel::windowList = 0;
 
 int default_open =  TopLevel::OPEN_READWRITE;
 
 TopLevel::TopLevel (QWidget *, const char *name)
-    : KMainWindow ( 0,name )
+  : KMainWindow ( 0,name )
 {
   mOptionDialog = 0;
   kspell = 0;
@@ -82,7 +71,7 @@ TopLevel::TopLevel (QWidget *, const char *name)
 
   if (!windowList)
   {
-     windowList = new QList<TopLevel>;
+     windowList = new QPtrList<TopLevel>;
      windowList->setAutoDelete( FALSE );
   }
   windowList->append( this );
@@ -114,19 +103,13 @@ TopLevel::~TopLevel ()
   delete mOptionDialog;
 }
 
-QString TopLevel::name()
-{
-  if (location.isEmpty())
-     return i18n("[New Document]");
-  return location;
-}
 
 
 void TopLevel::setupEditWidget()
 {
   eframe = new KEdit (this, "eframe");
   KCursor::setAutoHideCursor( eframe, true );
-  
+
   connect(eframe, SIGNAL(CursorPositionChanged()),this,
 	  SLOT(statusbar_slot()));
   connect(eframe, SIGNAL(toggle_overwrite_signal()),this,
@@ -163,7 +146,7 @@ void TopLevel::setupEditWidget()
   {
     eframe->setWordWrap(QMultiLineEdit::NoWrap);
   }
-  eframe->setFont( mOptionState.font.font );
+  setFontOption( mOptionState.font );
   eframe->setModified(false);
 
   setSensitivity();
@@ -264,10 +247,10 @@ void TopLevel::setupStatusBar()
 
 void TopLevel::saveProperties(KConfig* config)
 {
-  if(location.isEmpty() && !eframe->isModified())
+  if(m_url.isEmpty() && !eframe->isModified())
     return;
 
-  config->writeEntry("filename",name());
+  config->writeEntry("url",m_url.url());
   config->writeEntry("modified",eframe->isModified());
 
   int line, col;
@@ -277,28 +260,32 @@ void TopLevel::saveProperties(KConfig* config)
 
   if(eframe->isModified())
   {
-    QString tmplocation = kapp->tempSaveName(name());
-    saveFile(tmplocation, false);
+    QString name = m_url.url();
+    if (name.isEmpty())
+       name = QString("kedit%1-%2").arg(getpid()).arg((long)this);
+    QString tmplocation = kapp->tempSaveName(m_url.url());
+    config->writeEntry("saved_to",tmplocation);
+    saveFile(tmplocation, false, m_url.fileEncoding());
   }
 }
 
 
 void TopLevel::readProperties(KConfig* config){
 
-    QString filename = config->readEntry("filename","");
+    KURL url = config->readEntry("url");
+    QString filename = config->readEntry("saved_to");
+
+    QString encoding = url.fileEncoding();
     int modified = config->readNumEntry("modified",0);
     int line = config->readNumEntry("current_line", 0);
     int col = config->readNumEntry("current_column", 0);
 
     if(!filename.isEmpty() && modified){
-        bool ok;
-
-        QString fn = kapp->checkRecoverFile(filename,ok);
-
-	if(ok){
-	  openFile(fn, OPEN_READWRITE);
-	  location = filename;
-	  eframe->setModified();
+	int result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
+        if (result == KEDIT_OK)
+        {
+	  m_url = url;
+	  eframe->setModified(TRUE);
           eframe->setCursorPosition(line, col);
 	  setFileCaption();
           statusbar_slot();
@@ -307,12 +294,15 @@ void TopLevel::readProperties(KConfig* config){
     else{
 
       if(!filename.isEmpty()){
-	openFile(filename, OPEN_READWRITE);
-        location = filename;
-        eframe->setModified(false);
-        eframe->setCursorPosition(line, col);
-        setFileCaption();
-        statusbar_slot();
+	int result = openFile(filename, OPEN_READWRITE, url.fileEncoding());
+        if (result == KEDIT_OK)
+        {
+          m_url = url;
+          eframe->setModified(false);
+          eframe->setCursorPosition(line, col);
+          setFileCaption();
+          statusbar_slot();
+        }
       }
     }
 }
@@ -332,7 +322,7 @@ void TopLevel::redo()
 
 void TopLevel::copy()
 {
-  eframe->copyText();
+  eframe->copy();
 }
 
 
@@ -404,10 +394,10 @@ void TopLevel::spellcheck()
 
   connect (kspell, SIGNAL (progress (unsigned int)),
           this, SLOT (spell_progress (unsigned int)));
-  connect (kspell, SIGNAL (misspelling (QString, QStringList *, unsigned)),
-          eframe, SLOT (misspelling (QString, QStringList *, unsigned)));
-  connect (kspell, SIGNAL (corrected (QString, QString, unsigned)),
-          eframe, SLOT (corrected (QString, QString, unsigned)));
+  connect (kspell, SIGNAL (misspelling (const QString &, const QStringList &, unsigned int)),
+          eframe, SLOT (misspelling (const QString &, const QStringList &, unsigned int)));
+  connect (kspell, SIGNAL (corrected (const QString &, const QString &, unsigned int)),
+          eframe, SLOT (corrected (const QString &, const QString &, unsigned int)));
   connect (kspell, SIGNAL (done(const QString&)),
 		 this, SLOT (spell_done(const QString&)));
 }
@@ -464,15 +454,16 @@ void TopLevel::file_open( void )
 {
   while( 1 )
   {
-    KURL url = KFileDialog::getOpenURL( QString::null, "*", this,
-			i18n("Open File") );
+    KURL url = KTextFileDialog::getOpenURLwithEncoding(
+		QString::null, QString::null, this,
+		i18n("Open File"));
     if( url.isEmpty() )
     {
       return;
     }
 
     TopLevel *toplevel;
-    if( !location.isEmpty() || eframe->isModified() )
+    if( !m_url.isEmpty() || eframe->isModified() )
     {
       toplevel = new TopLevel();
       if( toplevel == 0 )
@@ -487,13 +478,13 @@ void TopLevel::file_open( void )
 
     QString tmpfile;
     KIO::NetAccess::download( url, tmpfile );
-    int result = toplevel->openFile( tmpfile, 0 );
+    int result = toplevel->openFile( tmpfile, 0, url.fileEncoding());
     KIO::NetAccess::removeTempFile( tmpfile );
 
     if( result == KEDIT_OK )
     {
       if( toplevel != this ) { toplevel->show(); }
-      toplevel->location = url.path();
+      toplevel->m_url = url;
       toplevel->setFileCaption();
       recent->addURL( url );
       toplevel->eframe->setModified(false);
@@ -517,8 +508,9 @@ void TopLevel::file_insert()
 {
   while( 1 )
   {
-    KURL url = KFileDialog::getOpenURL( QString::null, "*", this,
-			i18n("Insert File") );
+    KURL url = KTextFileDialog::getOpenURLwithEncoding(
+        QString::null, QString::null, this,
+	i18n("Insert File") );
     if( url.isEmpty() )
     {
       return;
@@ -526,7 +518,7 @@ void TopLevel::file_insert()
 
     QString tmpfile;
     KIO::NetAccess::download( url, tmpfile );
-    int result = openFile( tmpfile, OPEN_INSERT );
+    int result = openFile( tmpfile, OPEN_INSERT, url.fileEncoding() );
     KIO::NetAccess::removeTempFile( tmpfile );
 
     if( result == KEDIT_OK )
@@ -546,12 +538,18 @@ void TopLevel::file_insert()
 
 bool TopLevel::queryExit()
 {
+  // save recent files menu
+  config = kapp->config();
+  recent->saveEntries( config );
+  config->sync();
+
   return true;
 }
 
 bool TopLevel::queryClose()
 {
-  int result;
+    queryExit();
+    int result;
   if( !eframe->isModified() )
   {
      return true;
@@ -563,11 +561,11 @@ bool TopLevel::queryClose()
   switch( KMessageBox::warningYesNoCancel( this, msg ) )
   {
      case KMessageBox::Yes: // Save, then exit
-                    if( location.isEmpty())
+                    if( m_url.isEmpty())
                         file_save_as();
                     else
                         {
-	        result = saveFile(location);
+	        result = saveURL(m_url);
 	        if( result == KEDIT_USER_CANCEL )
 	                return false;
 	        if( result != KEDIT_OK)
@@ -601,9 +599,9 @@ bool TopLevel::queryClose()
 
 void TopLevel::openRecent(const KURL& url)
 {
-  if (!location.isEmpty() || eframe->isModified())
+  if (!m_url.isEmpty() || eframe->isModified())
   {
-     TopLevel *t = new TopLevel ();
+     TopLevel *t = new TopLevel (0,0);
      t->show();
      t->openRecent(url);
      return;
@@ -635,7 +633,7 @@ void TopLevel::file_close()
   }
   eframe->clear();
   eframe->setModified(false);
-  location = QString::null;
+  m_url = KURL();
   setFileCaption();
   statusbar_slot();
 }
@@ -643,36 +641,20 @@ void TopLevel::file_close()
 
 void TopLevel::file_save()
 {
-  if (location.isEmpty())
+  if (m_url.isEmpty())
   {
      file_save_as();
      return;
   }
-  if ( eframe->isModified() )
-  {
-      KURL u( location );
-      if ( !u.isMalformed() && u.protocol() != "file" )
-      {
-	
-	  url_location = location;
-	  saveURL( u );
-	  statusbar_slot();
-	  return;
-      }
 
-      int result = KEDIT_OK;
+  int result = KEDIT_OK;
 
-      result =  saveFile(location); // error messages are handled by saveFile
+  result =  saveURL(m_url); // error messages are handled by saveFile
 
-      if ( result == KEDIT_OK ){
-	  QString string;
-	  string = i18n("Wrote: %1").arg(location);
-	  setGeneralStatusField(string);
-      }
-  }
-  else
-  {
-      setGeneralStatusField(i18n("No changes need to be saved"));
+  if ( result == KEDIT_OK ){
+     QString string;
+     string = i18n("Wrote: %1").arg(m_caption);
+     setGeneralStatusField(string);
   }
 }
 
@@ -688,19 +670,22 @@ void TopLevel::setGeneralStatusField(const QString &text){
 
 void TopLevel::file_save_as()
 {
-  KURL u = KFileDialog::getSaveURL(location, "*", this,
-			i18n("Save File As"));
+  KURL u = KTextFileDialog::getSaveURLwithEncoding(
+	      m_url.url(), QString::null, this,
+	      i18n("Save File As"),
+	      m_url.fileEncoding());
   if (u.isEmpty())
-     return;
+    return;
 
   int result = saveURL(u); // error messages are handled by saveFile
 
   if ( result == KEDIT_OK )
     {
-      location = u.url();
+      m_url = u;
       setFileCaption();
-      QString string = i18n("Saved as: %1").arg(location);
+      QString string = i18n("Saved as: %1").arg(m_caption);
       setGeneralStatusField(string);
+      recent->addURL( u );
     }
 }
 
@@ -708,6 +693,8 @@ void TopLevel::file_save_as()
 
 void TopLevel::mail()
 {
+  // TODO: add charset box to mail dlg?
+
   Mail *maildlg = new Mail(this,"maildialog");
   if( maildlg->exec() == QDialog::Rejected )
   {
@@ -735,7 +722,17 @@ void TopLevel::mail()
     return;
   }
 
+  QString enc = m_url.fileEncoding();
   QTextStream t(mailpipe,IO_WriteOnly );
+  QTextCodec *codec;
+  if (!enc.isEmpty())
+    codec = QTextCodec::codecForName(enc.latin1());
+  else
+    codec = QTextCodec::codecForLocale();
+  t.setCodec(codec);
+
+  // t << "Content-Type: text/plain; charset=" << enc << "\n\n";
+
   int line_count = eframe->numLines();
 
   for(int i = 0 ; i < line_count ; i++){
@@ -840,6 +837,8 @@ void TopLevel::setFontOption( const SFontState &font )
 {
   mOptionState.font = font;
   eframe->setFont( mOptionState.font.font );
+  int w = eframe->fontMetrics().width("M");
+  eframe->setTabStopWidth(8*w);
 }
 
 
@@ -885,7 +884,7 @@ void TopLevel::toggleToolBar()
      toolBar("mainToolBar")->show();
   else
      toolBar("mainToolBar")->hide();
-}	
+}
 
 
 void TopLevel::toggleStatusBar()
@@ -905,9 +904,32 @@ void TopLevel::search_again()
 }
 
 
-void TopLevel::setFileCaption(){
-
-  setCaption(name());
+void TopLevel::setFileCaption()
+{
+  if (m_url.isEmpty())
+  {
+     m_caption = i18n("[New Document]");
+  }
+  else
+  {
+     if (m_url.isLocalFile())
+     {
+         if (QDir::currentDirPath() == m_url.directory())
+            m_caption = m_url.fileName();
+         else
+            m_caption = m_url.path();
+     }
+     else
+     {
+         KURL url(m_url);
+         url.setQuery(QString::null);
+         m_caption = url.prettyURL();
+     }
+     QString encoding = m_url.fileEncoding();
+     if (!encoding.isEmpty())
+        m_caption += QString(" (%1)").arg(encoding);
+  }
+  setCaption(m_caption);
 }
 
 
@@ -928,183 +950,107 @@ void TopLevel::statusbar_slot(){
 
 void TopLevel::print()
 {
-  QString command;
-  QString com;
-  QString file;
+    bool aborted = false;
+    QString headerLeft = i18n("Date: %1").arg(KGlobal::locale()->formatDate(QDate::currentDate(),true));
+    QString headerMid = i18n("File: %1").arg(m_caption);
+    QString headerRight;
 
-  int result;
+    QFont printFont = eframe->font();
+    QFont headerFont(printFont);
+    headerFont.setBold(true);
 
-  if( eframe->isModified() )
-  {
-    QString msg = i18n(""
-      "The current document has been modified.\n"
-      "Would you like to save the changes before\n"
-      "printing this document?");
-    switch( KMessageBox::warningYesNoCancel( this, msg ) )
-    {
-      case KMessageBox::Yes: // Save, then print
-                if(location.isEmpty())
-                        file_save_as();
-                else
-                        {
- 	        result = saveFile(location);
-	        if( result == KEDIT_USER_CANCEL )
-	                {
-	                return;
-	                }
-	        if( result != KEDIT_OK)
-	        {
-	        msg = i18n(""
-	                "Could not save the file.\n"
-	                "Print anyways?");
-	        switch( KMessageBox::warningYesNo( this, msg ) )
-	                {
-	                case KMessageBox::Yes:
-	                        break;
+    QFontMetrics printFontMetrics(printFont);
+    QFontMetrics headerFontMetrics(headerFont);
 
-	                case KMessageBox::No:
-	                        return;
-	                        break;
-	                }
-	        }
-                }
-      break;
+    KPrinter *printer = new KPrinter;
+    if(printer->setup(this)) {
+        // set up KPrinter
+        printer->setFullPage(false);
+        printer->setCreator("KEdit");
+        QString docname = m_caption;
+        if ( !docname.isEmpty() )
+	    printer->setDocName(docname);
 
-      case KMessageBox::No: // Don't save but print.
-      break;
+        QPainter *p = new QPainter;
+        p->begin( printer );
 
-      case KMessageBox::Cancel: // Don't save and don't print.
-	return;
-      break;
-    }
-  }
-
-  PrintDialog *printDialog = new PrintDialog(this,"print",true);
-  printDialog->setWidgets(pi);
-
-  if(printDialog->exec() == QDialog::Rejected )
-  {
-    delete printDialog;
-    return;
-  }
-
-  pi = printDialog->getCommand();
-  delete printDialog;
-
-  if( location.isEmpty() )
-  {
-    //
-    // we go through all of this so that we can print an "Untitled" document
-    // quickly without going through the hassle of saving it. This will
-    // however result in a temporary filename and your printout will
-    // usually show that temp name, such as /tmp/00432aaa
-    // for a non "untitled" document we don't want that to happen so
-    // we asked the user to save before we print the document.
-    //
-    // TODO find a smarter solution for the above!
-    //
-    QString tmpname = tmpnam(NULL);
-    QFile file(tmpname);
-    file.open(IO_WriteOnly);
-
-
-    if(pi.selection)
-    {
-      if(file.writeBlock(eframe->markedText().ascii(),
-			 eframe->markedText().length()) == -1)
-      {
-	result = KEDIT_OS_ERROR;
-      }
-      else
-      {
-	result = KEDIT_OK;
-      }
+        QPaintDeviceMetrics metrics( printer );
+
+        int dy = 0;
+
+	p->setFont(headerFont);
+        int w = printFontMetrics.width("M");
+        p->setTabStops(8*w);
+
+        int page = 1;
+        int lineCount = 0;
+        int maxLineCount = eframe->numLines();
+
+        KDialogBase *dlg = new KDialogBase(this, "printdialog", true, i18n("Printing"), KDialogBase::Ok, KDialogBase::Ok, true);
+        dlg->setButtonOKText(i18n("Stop"), i18n("Stop printing"));
+        QLabel *dlg_lbl = new QLabel(dlg);
+        dlg->setMainWidget(dlg_lbl);
+        dlg->setInitialSize(QSize(300,120));
+        dlg->show();
+     
+        while(true) {
+           QString lbl_txt = i18n("Printing page %1...").arg(page);
+           dlg_lbl->setText(lbl_txt);
+           kapp->flush();
+           kapp->processEvents();
+           kapp->flush();
+           if (dlg->isHidden())
+           {
+               aborted = true;
+               printer->abort();
+               break;
+           }
+           headerRight = QString("#%1").arg(page); 
+           dy = headerFontMetrics.lineSpacing();
+           QRect body( 0, dy*2,  metrics.width(), metrics.height()-dy*2);
+
+           p->drawText(0, 0, metrics.width(), dy, Qt::AlignLeft, headerLeft);
+           p->drawText(0, 0, metrics.width(), dy, Qt::AlignHCenter, headerMid);
+           p->drawText(0, 0, metrics.width(), dy, Qt::AlignRight, headerRight);
+
+           QPen pen;
+           pen.setWidth(3);
+           p->setPen(pen);
+
+           p->drawLine(0, dy+dy/2, metrics.width(), dy+dy/2);    
+
+           int y = dy*2;
+           while(lineCount < maxLineCount) {
+              QString text = eframe->textLine(lineCount);
+              QRect r = p->boundingRect(0, y, body.width(), body.height(), 
+			QPainter::ExpandTabs | QPainter::WordBreak, text);
+
+              dy = r.height();
+
+              if (y+dy > metrics.height()) break;
+
+              p->drawText(0, y, metrics.width(), metrics.height() - y, 
+                        QPainter::ExpandTabs | QPainter::WordBreak, text);
+
+              y += dy;
+              lineCount++;
+           }
+           if (lineCount >= maxLineCount)
+              break;  
+
+           printer->newPage();
+           page++;
+        }
+        delete dlg;
+
+        p->end();
+        delete p;
     }
+    delete printer;
+    if (aborted)
+      setGeneralStatusField(i18n("Printing aborted."));
     else
-    {
-      if(file.writeBlock(eframe->text().ascii(),
-			 eframe->text().length()) == -1)
-      {
-	result = KEDIT_OS_ERROR;
-      }
-      else
-      {
-	result = KEDIT_OK;
-      }
-    }
-
-    file.close();
-    // TODO error handling
-
-    if (pi.raw)
-    {
-      command = "lpr";
-    }
-    else
-    {
-      command = pi.command;
-    }
-    com = QString("%1 %2 ; rm %3 &").arg(command).arg(tmpname).arg(tmpname);
-    system(com.ascii());
-    QString string;
-    if(pi.selection)
-      string = i18n("Printing: %1 Untitled (Selection)").arg(command);
-    else
-      string = i18n("Printing: %1 Untitled").arg(command);
-    setGeneralStatusField(string);
-  }
-  else // document name != Untiteled
-  {
-    QString tmpname = tmpnam(NULL);
-    if( pi.selection )
-    {
-      // print only the selection
-      QFile file(tmpname);
-      file.open(IO_WriteOnly);
-
-
-      if(file.writeBlock(eframe->markedText().ascii(),
-			 eframe->markedText().length()) == -1)
-      {
-	result = KEDIT_OS_ERROR;
-      }
-      file.close();
-      // TODO error handling
-    }
-
-    if(pi.raw)
-    {
-      command = "lpr";
-    }
-    else
-    {
-      command = pi.command;
-    }
-
-    if(!pi.selection) // print the whole file
-    {
-      //com = QString ("%1 '%2' &").arg(command).arg(location);
-      QString tmpFile;
-      if( KIO::NetAccess::download( location, tmpFile ) )
-	{
-	  com = QString ("%1 '%2' &").arg(command).arg(tmpFile);
-	  system(com.ascii());
-	  KIO::NetAccess::removeTempFile( tmpFile );
-	  QString string;
-	  string = i18n("Printing: %1").arg(com);
-	  setGeneralStatusField(string);
-       }
-    }
-    else // print only the selection
-    {
-      com = QString ("%1 %2 ; rm %3 &").arg(command).arg(tmpname).arg(tmpname);
-      system(com.ascii());
-      QString string = i18n("Printing: %1 %2 (Selection)")
-	.arg(command).arg(location);
-      setGeneralStatusField(string);
-    }
-    //kdDebug(0) << com.ascii() << endl;
-  }
+      setGeneralStatusField(i18n("Printing complete."));
 }
 
 
@@ -1131,13 +1077,13 @@ int TopLevel::saveURL( const KURL& _url )
     // Just a usual file ?
     if ( _url.isLocalFile() )
     {
-        return saveFile( _url.url() );
+        return saveFile( _url.path(), true, _url.fileEncoding() );
     }
 
     KTempFile tmpFile;
     tmpFile.setAutoDelete(true);
     eframe->setModified( true );
-    saveFile( tmpFile.name(), false );
+    saveFile( tmpFile.name(), false, _url.fileEncoding() );
 
     if (KIO::NetAccess::upload( tmpFile.name(), _url ) == false)
     {
@@ -1148,23 +1094,9 @@ int TopLevel::saveURL( const KURL& _url )
     return true;
 }
 
-int TopLevel::openFile( const QString& _url, int _mode )
+int TopLevel::openFile( const QString& _filename, int _mode, const QString &encoding )
 {
-  location=_url;
-  setFileCaption();
-  KURL *u = new KURL( _url );
-  if ( u->isMalformed() )
-  {
-     KMessageBox::sorry(this, i18n("This is not a valid filename.\n"));
-     return KEDIT_RETRY;
-  }
-  if ( !u->isLocalFile() )
-  {
-     KMessageBox::sorry(this, i18n("This is not a local file.\n"));
-     return KEDIT_RETRY;
-  }
-
-  QFileInfo info(u->path());
+  QFileInfo info(_filename);
 
   if(!info.exists())
   {
@@ -1180,7 +1112,7 @@ int TopLevel::openFile( const QString& _url, int _mode )
      return KEDIT_RETRY;
   }
 
-  QFile file(u->path());
+  QFile file(_filename);
 
   if(!file.open(IO_ReadOnly))
   {
@@ -1189,6 +1121,13 @@ int TopLevel::openFile( const QString& _url, int _mode )
   }
 
   QTextStream stream(&file);
+  QTextCodec *codec;
+  if (!encoding.isEmpty())
+    codec = QTextCodec::codecForName(encoding.latin1());
+  else
+    codec = QTextCodec::codecForLocale();
+  stream.setCodec(codec);
+
   if ((_mode & OPEN_INSERT) == 0)
   {
      eframe->clear();
@@ -1291,21 +1230,9 @@ static bool backupFile( const QString &qFilename)
 }
 
 
-int TopLevel::saveFile( const QString& _url, bool backup )
+int TopLevel::saveFile( const QString& _filename, bool backup, const QString& encoding )
 {
-  KURL *u = new KURL( _url );
-  if ( u->isMalformed() )
-  {
-     KMessageBox::sorry(this, i18n("This is not a valid filename.\n"));
-     return KEDIT_RETRY;
-  }
-  if ( !u->isLocalFile() )
-  {
-     KMessageBox::sorry(this, i18n("This is not a local file.\n"));
-     return KEDIT_RETRY;
-  }
-
-  QFileInfo info(u->path());
+  QFileInfo info(_filename);
 
   if(info.isDir())
   {
@@ -1313,9 +1240,9 @@ int TopLevel::saveFile( const QString& _url, bool backup )
      return KEDIT_RETRY;
   }
 
-  if (backup && mOptionState.misc.backupCheck && QFile::exists(u->path()))
+  if (backup && mOptionState.misc.backupCheck && QFile::exists(_filename))
   {
-     if (!backupFile(u->path()))
+     if (!backupFile(_filename))
      {
         KMessageBox::sorry(this, i18n("Unable to make a backup of the original file."));
      }
@@ -1325,13 +1252,20 @@ int TopLevel::saveFile( const QString& _url, bool backup )
   // links when saving. Most applications don't care about this, but an
   // editor is supposed to preserve such things.
 
-  QFile file(u->path());
+  QFile file(_filename);
   if(!file.open(IO_WriteOnly))
   {
      KMessageBox::sorry(this, i18n("Unable to write to file."));
      return KEDIT_RETRY;
   }
+
   QTextStream textStream(&file);
+  QTextCodec *codec;
+  if (!encoding.isEmpty())
+    codec = QTextCodec::codecForName(encoding.latin1());
+  else
+    codec = QTextCodec::codecForLocale();
+  textStream.setCodec(codec);
 
   eframe->saveText( &textStream );
   file.close();
@@ -1348,29 +1282,32 @@ int TopLevel::saveFile( const QString& _url, bool backup )
 
 void TopLevel::openURL( const KURL& _url, int _mode )
 {
-    QString netFile = _url.url();
-    kdDebug() << "TopLEvel::openUrl: " << netFile << endl;
     if ( _url.isMalformed() )
     {
         QString string;
-        string = i18n( "Malformed URL\n%1").arg(netFile);
+        string = i18n( "Malformed URL\n%1").arg(_url.url());
 
         KMessageBox::sorry(this, string);
         return;
     }
 
     QString target;
-    if (KIO::NetAccess::download(_url, target) == false)
+    int result = KEDIT_OK;
+    if (KIO::NetAccess::download(_url, target))
     {
-      // this needs to be handled within KIO sooooon
-      KMessageBox::error(this, i18n("Cannot download file!"));
-      return;
+       result = openFile(target, _mode, _url.fileEncoding());
+    }
+    else
+    {
+      if (_mode & OPEN_NEW == 0)
+      {     
+         KMessageBox::error(this, i18n("Cannot download file!"));
+         return;
+      }
     }
-
-    int result = openFile(target, 0);
     if (result == KEDIT_OK)
     {
-        location = netFile;
+        m_url = _url;
         setFileCaption();
         recent->addURL(_url);
         eframe->setModified(false);
@@ -1457,9 +1394,6 @@ void TopLevel::readSettings( void )
   // Default settings. The values in mOptionState is defined in
   // optionstate.h
   //
-  pi.command = "enscript -2rG";
-  pi.raw = 1;
-  pi.selection = 0;
 
   QString str;
   config = kapp->config();
@@ -1469,10 +1403,7 @@ void TopLevel::readSettings( void )
     &mOptionState.font.font);
 
   recent->loadEntries( config );
-
   config->setGroup("General Options");
-  url_location = config->readEntry( "default_url",
-    "ftp://localhost/welcome.msg" );
 
   mOptionState.misc.mailCommand = config->readEntry("MailCmd",
     mOptionState.misc.mailCommand );
@@ -1508,20 +1439,6 @@ void TopLevel::readSettings( void )
   toolbarAction->setChecked(!toolBar()->isHidden());
 
   ///////////////////////////////////////////////////
-
-  config->setGroup("Printing");
-  str = config->readEntry("PrntCmd1");
-  if ( str.isNull() == false )
-    pi.command = str;
-
-  str = config->readEntry("PrintSelection");
-  if ( str.isNull() == false )
-    pi.selection = str.toInt();
-
-  str = config->readEntry("PrintRaw");
-  if ( str.isNull() == false )
-    pi.raw = str.toInt();
-
 }
 
 void TopLevel::writeSettings( void )
@@ -1537,8 +1454,6 @@ void TopLevel::writeSettings( void )
   saveMainWindowSettings(config);
 
   config->setGroup("General Options");
-  config->writeEntry("default_url", url_location);
-
   config->writeEntry("MailCmd", mOptionState.misc.mailCommand );
 
   QString string;
@@ -1561,24 +1476,13 @@ void TopLevel::writeSettings( void )
   QColor &bg = mOptionState.color.textBg;
   string.sprintf("#%02x%02x%02x", bg.red(),bg.green(), bg.blue());
   config->writeEntry( "BackColor", string );
-	
+
   ////////////////////////////////////////////////////
 
-  config->setGroup("Printing");
-
-  config->writeEntry("PrntCmd1", pi.command);
-
-  string.setNum( pi.selection );
-  config->writeEntry("PrintSelection", string);
-
-  string.setNum( pi.raw );
-  config->writeEntry("PrintRaw", string);
-
   config->sync();
 }
 
 
-
 void TopLevel::toggle_overwrite(){
 
   if(eframe->isOverwriteMode()){
@@ -1600,7 +1504,6 @@ static const KCmdLineOptions options[] =
 
 int main (int argc, char **argv)
 {
-(void) malloc(10);
 	bool have_top_window = false;
 
 	KAboutData aboutData( "kedit", I18N_NOOP("KEdit"),
@@ -1629,7 +1532,7 @@ int main (int argc, char **argv)
 	{
 		have_top_window = false;
 		KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
-	
+
 		for(int i = 0; i < args->count(); i++)
 		{
 			TopLevel *t = new TopLevel;
@@ -1637,14 +1540,11 @@ int main (int argc, char **argv)
 			have_top_window = true;
 
 			KURL url = args->url(i);
-			if( url.isLocalFile() )
-				t->openFile(url.path(), default_open | TopLevel::OPEN_NEW);	
-			else
-				t->openURL( url, default_open );
+			t->openURL( url, default_open | TopLevel::OPEN_NEW );
 		}
 		args->clear();
 	}
-	
+
 	if(!have_top_window)
 	{
 		TopLevel *t = new TopLevel ();
@@ -1655,5 +1555,7 @@ int main (int argc, char **argv)
 }
 
 
+
+
 #include "kedit.moc"
 
