@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.55 2001/01/21 07:22:58 waba Exp $
+    $Id: kedit.h,v 1.61 2001/10/14 04:16:55 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -25,16 +25,19 @@
 #define _KEDIT_H_
 
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
+#include <qtextcodec.h>
 #include <qptrdict.h>
 
 #include "optionstate.h"
-#include "print.h"
 #include "version.h"
 
 #include <kmainwindow.h>
 #include <keditcl.h>
+#include <kurl.h>
+#include <kaction.h>
+#include <kstdaction.h>
 
 class COptionDialog;
 class KSpell;
@@ -73,14 +76,14 @@ public:
      *
      * @return KEDIT_OK on success
      */
-    int openFile( const QString& _url, int _mode);
+    int openFile( const QString& _filename, int _mode, const QString &encoding);
 
     /**
      * Saves the edit widget to a file.
      *
      * @return KEDIT_OK on success
      */
-    int saveFile( const QString& _url, bool backup=true);
+    int saveFile( const QString& _filename, bool backup, const QString &encoding);
 
     /**
      * Works like openFile but is able to open remote files
@@ -95,18 +98,18 @@ public:
     
     int saveURL( const KURL& _url );
 
-    /**
-     * Get the name of the current file
-     **/
-    QString name();
-
     /**
      * Only show the window when the following load action is succesfull.
      **/
     void setNewWindow() { newWindow = true; }
 
+    /**
+     * set url
+     */
+    void setUrl(const KURL &url) { m_url = url; }
+
     /// List of all windows
-    static QList<TopLevel> *windowList;
+    static QPtrList<TopLevel> *windowList;
     QPopupMenu *right_mouse_button;
 
     bool queryExit( void );
@@ -124,11 +127,11 @@ private:
 public:  // Should not be!
     KEdit *eframe;
 private:
-    QString location;
+    KURL m_url;
+    QString m_caption;
 
     bool newWindow;
     int statusID, toolID, indentID;
-    QString url_location;
     QTimer *statusbar_timer;
     KRecentFilesAction *recent;
     KToggleAction *statusbarAction;
@@ -139,7 +142,6 @@ private:
     KAction *redoAction;
 
     int open_mode;
-    struct printinfo pi;
 
     SOptionState mOptionState;
 
