@@ -20,19 +20,16 @@
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
-#include <qfont.h>
-#include <qframe.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlineedit.h> 
 #include <qvbox.h>
+#include <knumvalidator.h>
 
-#include <kapp.h>
-#include <kcolorbtn.h>
+#include <kcolorbutton.h>
 #include <kfontdialog.h> // For KFontChooser
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kspell.h>
 
 #include "optiondialog.h"
 #include "optiondialog.moc"
@@ -138,6 +135,7 @@ void COptionDialog::setupMiscPage( void )
   mMisc.wrapLabel = new QLabel( text, page, "wrapcolumn" );
   gbox->addWidget( mMisc.wrapLabel, 1, 0 );
   mMisc.wrapInput = new QLineEdit( page, "values" );
+  mMisc.wrapInput->setValidator( new KIntValidator( 0,9999,mMisc.wrapInput ) );
   mMisc.wrapInput->setMinimumWidth( fontMetrics().maxWidth()*10 );
   gbox->addWidget( mMisc.wrapInput, 1, 1 );
 
@@ -184,6 +182,7 @@ void COptionDialog::slotApply( void )
       emit colorChoice( mState.color );
 
       mState.spell.config = *mSpell.config;
+      mState.spell.config.writeGlobalSettings();
       emit spellChoice( mState.spell );
 
       mState.misc.wrapMode    = mMisc.wrapCombo->currentItem();
