@@ -1,6 +1,6 @@
     /*
 
-    $Id: floppy.h,v 1.8 1999/10/09 14:55:40 bieker Exp $
+    $Id: floppy.h,v 1.17 2001/12/21 23:02:29 howells Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
@@ -46,54 +46,37 @@
 #include <kprocess.h>
 #include <klocale.h>
 #include <kconfig.h>
-#include "about.h"
 #include <kapp.h>
+#include <kdialog.h>
+#include <khelpmenu.h>
+#include <kpopupmenu.h>
 
-
-#define EXT2_MF_MOUNTED		1
-#define EXT2_MF_ISROOT		2
-#define EXT2_MF_READONLY	4 
-
-#define FLOPPYA3 "A: 3.5"
-#define FLOPPYA5 "A: 5.25"
-#define FLOPPYB3 "B: 3.5"
-#define FLOPPYB5 "B: 5.25"
-
-class FloppyData : public QWidget
+class FloppyData : public KDialog
 {
     Q_OBJECT
 
 public:
-
-    FloppyData
-    (
-        QWidget* parent = NULL,
-        const char* name = NULL
-    );
-
+    FloppyData(QWidget* parent = 0, const char * name = 0);
     virtual ~FloppyData();
-    void addDevice(const char* name);
-    void addFileSystem(const char* name);
-    void addDensity(const char* name);
+
+    void addDevice(const QString & name);
+    void show();
+    void addFileSystem(const QString & name);
+    void addDensity(const QString & name);
     bool findDevice();
-    bool findExecutables();
+    void findExecutables();
     void closeEvent(QCloseEvent*);
     void writeSettings();
     void readSettings();
     void setWidgets();
-    int findKeyWord(QString&,const char*);
-    bool checkmount();
-
+    int findKeyWord(QString &, const QString &);
     
 public slots:
       void fserrslot();
       void errslot();
-      void filesystemchanged(int);
       void quit();
       void format();
       void createfilesystem();
-      void about();
-      void help();
       void reset();
 
       void formatdone(KProcess* );
@@ -109,14 +92,16 @@ protected slots:
 
 private:
 
+        QString fdformat, mke2fs, mkdosfs; 
 
+        int verifyconfig;
         int labelconfig;
         QString labelnameconfig;
 	int quickformatconfig;
 	QString driveconfig;
 	QString densityconfig;
 	QString filesystemconfig;
-	QString mdev;
+	//QString mdev;
 	KConfig *config;
 
 	QString formatstring;
@@ -141,10 +126,10 @@ private:
         QLabel*       label2;        
 	QLabel*       label3;
 	QButtonGroup* buttongroup;
+	QCheckBox*    verifylabel;
 	QCheckBox*    labellabel;
 	QLineEdit*    lineedit;
 	QRadioButton* quick;
-	QPushButton* aboutbutton;
 	QPushButton* quitbutton;
 	QPushButton* helpbutton;
 	QRadioButton* fullformat;
@@ -154,6 +139,7 @@ private:
 	QComboBox* filesystemComboBox;
 	QComboBox* densityComboBox;
 	KProgress* progress;
+	KHelpMenu* helpMenu;
 
 protected:
 
