@@ -18,9 +18,8 @@
  *
  */
 
-#include <kapp.h>
 #include <klocale.h>
-#include <kaboutdialog_private.h>
+#include <qlabel.h>
 
 #include "aboutdialog.h"
 #include "version.h" // Contains khexedit name string and version string
@@ -58,7 +57,7 @@ CAboutKHexEdit::CAboutKHexEdit( QWidget *parent, const char *name, bool modal )
     "\n"
     "This program is distributed in the hope that it will be useful,\n"
     "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n"
     "GNU General Public License for more details.\n"
     "\n"
     "You should have received a copy of the GNU General Public License\n"
@@ -79,7 +78,7 @@ CAboutKHexEdit::CAboutKHexEdit( QWidget *parent, const char *name, bool modal )
 
     c->addPerson(QString::null,
       QString("espensa@online.no"),
-      QString("http://home.sol.no/~espensa/khexedit/"),
+      QString("http://home.online.no/~espensa/khexedit/"),
       QString::null, true );
   }
 
@@ -93,3 +92,4 @@ CAboutKHexEdit::~CAboutKHexEdit( void )
 
 
 
+#include "aboutdialog.moc"
