@@ -20,7 +20,7 @@
 
 #include <ctype.h>
 #include <iostream>
-#include <values.h>
+#include <limits.h>
 
 #include <qbuttongroup.h> 
 #include <qfileinfo.h> 
@@ -943,7 +943,7 @@ void CFilterDialog::makeRotateLayout( void )
   mGroupSpin = new QSpinBox( page );
   if( mGroupSpin == 0 ) { return; }
   mGroupSpin->setMinimumWidth( fontMetrics().width("M")*20 );
-  mGroupSpin->setRange(1, MAXINT );  
+  mGroupSpin->setRange(1, INT_MAX );  
 
   text = i18n("&Group size [bytes]");
   QLabel *label = new QLabel( mGroupSpin, text, page );
@@ -955,7 +955,7 @@ void CFilterDialog::makeRotateLayout( void )
   mBitSpin = new QSpinBox( page );
   if( mBitSpin == 0 ) { return; }
   mBitSpin->setMinimumWidth( fontMetrics().width("M")*20 );
-  mBitSpin->setRange(-MAXINT, MAXINT);
+  mBitSpin->setRange(INT_MIN, INT_MAX);
 
   text = i18n("S&hift size [bits]");
   label = new QLabel( mBitSpin, text, page );
@@ -1101,7 +1101,7 @@ CInsertDialog::CInsertDialog( QWidget *parent, const char *name, bool modal )
   mSizeBox = new QSpinBox( plainPage() );
   if( mSizeBox == 0 ) { return; }
   mSizeBox->setMinimumWidth( fontMetrics().maxWidth()*17 );
-  mSizeBox->setRange( 1, MAXINT );
+  mSizeBox->setRange( 1, INT_MAX );
   mSizeBox->setValue( 1 );
   
   QLabel *label = new QLabel( mSizeBox, i18n("&Size"), plainPage() );
