@@ -25,14 +25,14 @@
 #include <config.h>
 #endif 
 
-#include <iostream.h>
+#include <iostream>
 #include <time.h>
 
 #include <qbitarray.h> 
 #include <qdatetime.h> 
 #include <qfile.h>
 #include <qfont.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpainter.h>
 #include <qstring.h>
 #include <qtextstream.h>
@@ -276,7 +276,7 @@ class CStringCollectControl
       return( mList.count() );
     }
 
-    QList<QString> &list( void )
+    QPtrList<QString> &list( void )
     {
       return( mList );
     }
@@ -287,7 +287,7 @@ class CStringCollectControl
     bool allow8bit;
 
   private:
-    QList<QString> mList;
+    QPtrList<QString> mList;
 };
 
 
@@ -432,8 +432,8 @@ struct SCursorSpec
 
   void dump( void )
   {
-    cout << "offset: " << offset << " y: " << y << " x1: " << x1 << endl;
-    cout << "x2: " << x2 << " cell: " << cell << endl;
+    std::cout << "offset: " << offset << " y: " << y << " x1: " << x1 << std::endl;
+    std::cout << "x2: " << x2 << " cell: " << cell << std::endl;
   }
 
   bool inside( uint min, uint max )
@@ -1079,7 +1079,7 @@ class CHexBuffer : public QByteArray
 
     bool matchWidth( uint width );
 
-    void setNonPrintChar( char nonPrintChar );
+    void setNonPrintChar( QChar nonPrintChar );
     void setShowCursor( bool showCursor );
     void setDisableCursor( bool disableCursor );
     void setCursorShapeModifier( bool alwaysBlock, bool thickInsert );
@@ -1159,7 +1159,7 @@ class CHexBuffer : public QByteArray
     inline const SDisplayLayout &layout( void );
 
     inline const SDisplayInputMode &inputMode( void );
-    inline QList<SCursorOffset> &bookmarkList( void );
+    inline QPtrList<SCursorOffset> &bookmarkList( void );
 
     inline bool documentPresent( void );
     inline bool modified( void );
@@ -1348,50 +1348,55 @@ class CHexBuffer : public QByteArray
 
     uint mUndoLimit;
     uint mUndoIndex;
-    QList<CHexActionGroup> mUndoList;
-    QList<SCursorOffset> mBookmarkList;
+    QPtrList<CHexActionGroup> mUndoList;
+    QPtrList<SCursorOffset> mBookmarkList;
     QBitArray mBookmarkMap;
 
     PrintCellFunc   printCell;
     PrintOffsetFunc printOffset;
     InputCellFunc   inputCell;
 
+    static char mHexBigBuffer[16];
+    static char mHexSmallBuffer[16];
+    static char mDecBuffer[10];
+    static char mOctBuffer[8];
+    static SCursorState mCursorState;
+    static SFileState mFileState;
 };
 
 
 
 inline SCursorState &CHexBuffer::cursorState( void )
 {
-  static SCursorState state;
   if( size() == 0 )
   {
-    state.valid           = false;
-    state.selectionOffset = 0;
-    state.selectionSize   = 0;
-    state.offset          = 0;
-    state.cell            = 0;
-    state.undoState       = 0;
-    memset( state.data, 0, sizeof(state.data) );
-    state.charValid       = false;
+    mCursorState.valid           = false;
+    mCursorState.selectionOffset = 0;
+    mCursorState.selectionSize   = 0;
+    mCursorState.offset          = 0;
+    mCursorState.cell            = 0;
+    mCursorState.undoState       = 0;
+    memset( mCursorState.data, 0, sizeof(mCursorState.data) );
+    mCursorState.charValid       = false;
   }
   else
   {
-    state.valid           = true;
-    state.selectionOffset = mSelect.start();
-    state.selectionSize   = mSelect.size();
-    state.offset          = cursorOffset();
-    state.cell            = cursorBit();
-    state.undoState       = undoState();
+    mCursorState.valid           = true;
+    mCursorState.selectionOffset = mSelect.start();
+    mCursorState.selectionSize   = mSelect.size();
+    mCursorState.offset          = cursorOffset();
+    mCursorState.cell            = cursorBit();
+    mCursorState.undoState       = undoState();
 
-    for( uint i = 0; i < sizeof( state.data ); i++ )
+    for( uint i = 0; i < sizeof( mCursorState.data ); i++ )
     {
-      state.data[i] = (state.offset+i >= mDocumentSize) ? 0 : 
-	(unsigned char)data()[state.offset+i];
+      mCursorState.data[i] = (mCursorState.offset+i >= mDocumentSize) ? 0 : 
+	(unsigned char)data()[mCursorState.offset+i];
     }
 
-    state.charValid      = mCharValid[ state.data[0] ];
+    mCursorState.charValid      = mCharValid[ mCursorState.data[0] ];
   }
-  return( state );
+  return( mCursorState );
 }
 
 
@@ -1423,7 +1428,7 @@ inline const SDisplayInputMode &CHexBuffer::inputMode( void )
   return( mInputMode );
 }
 
-inline QList<SCursorOffset> &CHexBuffer::bookmarkList( void )
+inline QPtrList<SCursorOffset> &CHexBuffer::bookmarkList( void )
 {
   return( mBookmarkList );
 }
@@ -1433,22 +1438,21 @@ inline QList<SCursorOffset> &CHexBuffer::bookmarkList( void )
 
 inline SFileState &CHexBuffer::fileState( void )
 {
-  static SFileState state;
   if( size() == 0 )
   {
-    state.valid    = false;
-    state.size     = 0;
-    state.modified = false;
+    mFileState.valid    = false;
+    mFileState.size     = 0;
+    mFileState.modified = false;
 
   }
   else
   {
-    state.valid    = true;
-    state.size     = mDocumentSize;
-    state.modified = mDocumentModified;
+    mFileState.valid    = true;
+    mFileState.size     = mDocumentSize;
+    mFileState.modified = mDocumentModified;
   }
 
-  return( state );
+  return( mFileState );
 }
 
 
@@ -1879,52 +1883,35 @@ inline int CHexBuffer::printDummyCell( char *buf, unsigned char )
 
 inline int CHexBuffer::printHexadecimalBigCell( char *buf, unsigned char data )
 {
-  static char hexBuffer[16]=
-  {
-    '0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F'
-  };
-  buf[0] = hexBuffer[ (data>>4)&0x0F ];
-  buf[1] = hexBuffer[ data&0x0F ];
+  buf[0] = mHexBigBuffer[ (data>>4)&0x0F ];
+  buf[1] = mHexBigBuffer[ data&0x0F ];
   return( 0 );
 }
 
 inline int CHexBuffer::printHexadecimalSmallCell( char *buf, 
 						  unsigned char data )
 {
-  static char hexBuffer[16]=
-  {
-    '0','1','2','3','4','5','6','7','8','9','a','b','c','d','e','f'
-  };
-  buf[0] = hexBuffer[ (data>>4)&0x0F ];
-  buf[1] = hexBuffer[ data&0x0F ];
+  buf[0] = mHexSmallBuffer[ (data>>4)&0x0F ];
+  buf[1] = mHexSmallBuffer[ data&0x0F ];
   return( 0 );
 }
 
 
 inline int CHexBuffer::printDecimalCell( char *buf, unsigned char data )
 {
-  static char decBuffer[10]=
-  {
-    '0','1','2','3','4','5','6','7','8','9'
-  };
-  buf[0] = decBuffer[ data/100 ];
+  buf[0] = mDecBuffer[ data/100 ];
   data -= (data/100) * 100;
-  buf[1] = decBuffer[ data/10 ];
+  buf[1] = mDecBuffer[ data/10 ];
   data -= (data/10) * 10;
-  buf[2] = decBuffer[ data ];
+  buf[2] = mDecBuffer[ data ];
   return( 0 );
 }
 
 inline int CHexBuffer::printOctalCell( char *buf, unsigned char data )
 {
-  static char hexBuffer[8]=
-  {
-    '0','1','2','3','4','5','6','7'
-  };
-
-  buf[0] = hexBuffer[ (data>>6)&0x07 ];
-  buf[1] = hexBuffer[ (data>>3)&0x07 ];
-  buf[2] = hexBuffer[ data&0x07 ];
+  buf[0] = mOctBuffer[ (data>>6)&0x07 ];
+  buf[1] = mOctBuffer[ (data>>3)&0x07 ];
+  buf[2] = mOctBuffer[ data&0x07 ];
   return( 0 );
 }
 
