@@ -19,19 +19,16 @@
  */
 
 
-#include <iostream.h>
+#include <iostream>
 #include <unistd.h>
 
 #undef Unsorted
-#include <qdir.h>
 
-#include <kapp.h>
 #include <kfiledialog.h>
 #include <kglobalsettings.h>
 #include <kio/job.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <kurl.h>
 
 #include "chartabledialog.h"
 #include "converterdialog.h"
@@ -72,7 +69,7 @@ CHexEditorWidget::CHexEditorWidget( QWidget *parent, const char *name )
 	   this, SLOT( inputModeChanged( const SDisplayInputMode & ) ) );
 
   mHexView->setFocus();
-  setBackgroundColor( palette().normal().base() );
+  setBackgroundColor( palette().active().base() );
 
   mProgressBusy    = false;
   mGotoDialog      = 0;
@@ -460,26 +457,26 @@ void CHexEditorWidget::setColor( const SDisplayColor &color )
   //
   // The selection colors can not be chosen.
   //
-  mDisplayState.color.selectBg = kapp->palette().normal().highlight();
-  mDisplayState.color.selectFg = kapp->palette().normal().highlightedText();
+  mDisplayState.color.selectBg = kapp->palette().active().highlight();
+  mDisplayState.color.selectFg = kapp->palette().active().highlightedText();
 
   if( mDisplayState.color.useSystemColor == true )
   {
     SDisplayColor c = mDisplayState.color;
-    c.textBg           = kapp->palette().normal().base();
-    c.secondTextBg     = kapp->palette().normal().base();
-    c.offsetBg         = kapp->palette().normal().base();
-    c.inactiveBg       = kapp->palette().normal().base();
-    c.primaryFg[0]     = kapp->palette().normal().text();
-    c.primaryFg[1]     = kapp->palette().normal().text();
-    c.nonPrintFg       = kapp->palette().normal().text();
-    c.offsetFg         = kapp->palette().normal().text();
-    c.secondaryFg      = kapp->palette().normal().text();
-    c.leftSeparatorFg  = kapp->palette().normal().text();
-    c.rightSeparatorFg = kapp->palette().normal().text();
-    c.cursorBg         = kapp->palette().normal().text();
-    c.cursorFg         = kapp->palette().normal().base();
-    c.gridFg           = kapp->palette().normal().text();
+    c.textBg           = kapp->palette().active().base();
+    c.secondTextBg     = kapp->palette().active().base();
+    c.offsetBg         = kapp->palette().active().base();
+    c.inactiveBg       = kapp->palette().active().base();
+    c.primaryFg[0]     = kapp->palette().active().text();
+    c.primaryFg[1]     = kapp->palette().active().text();
+    c.nonPrintFg       = kapp->palette().active().text();
+    c.offsetFg         = kapp->palette().active().text();
+    c.secondaryFg      = kapp->palette().active().text();
+    c.leftSeparatorFg  = kapp->palette().active().text();
+    c.rightSeparatorFg = kapp->palette().active().text();
+    c.cursorBg         = kapp->palette().active().text();
+    c.cursorFg         = kapp->palette().active().base();
+    c.gridFg           = kapp->palette().active().text();
     SDisplayColor defaultColor;
     c.bookmarkBg       = defaultColor.bookmarkBg;
     c.bookmarkFg       = defaultColor.bookmarkFg;
@@ -1022,7 +1019,7 @@ void CHexEditorWidget::reload( void )
 
   if( mHexView->urlValid() == false )
   {
-    QString msg = i18n( "Current document does not exist on disk." );
+    QString msg = i18n( "The current document does not exist on the disk." );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Reload") );
     return;
   }
@@ -1032,20 +1029,17 @@ void CHexEditorWidget::reload( void )
     QString msg;
     if( modifiedByAlien( mHexView->url() ) == true )
     {
-      msg += i18n(""
-        "Current document been changed on disk and\n"
-        "contains unsaved modifications as well.\n" );
+      msg += i18n("The current document has changed on the disk and "
+                  "also contains unsaved modifications.\n" );
     }
     else
     {
-      msg += i18n( "Current document contains unsaved modifications.\n" );
+      msg += i18n( "The current document contains unsaved modifications.\n" );
     }
 
-    msg += i18n(""
-      "If you reload now, the modifications will be lost.\n"
-      "Proceed?" );
-    int reply = KMessageBox::warningYesNo(topLevelWidget(),msg,i18n("Reload"));
-    if( reply != KMessageBox::Yes )
+    msg += i18n("If you reload now, the modifications will be lost.");
+    int reply = KMessageBox::warningContinueCancel(topLevelWidget(),msg,i18n("Reload"), i18n("&Reload"));
+    if( reply != KMessageBox::Continue )
     {
       return;
     }
@@ -1265,12 +1259,11 @@ void CHexEditorWidget::encode( CConversion::EMode mode )
   {
     QString msg = i18n(""
       "The encoding you have selected is not reversible.\n"
-      "If you revert to the original encoding later, there is no\n"
-      "guarantee that the data can be restored to the original state.\n\n"
-      "Proceed?");
-    int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
-					   i18n("Encode") );
-    if( reply != KMessageBox::Yes )
+      "If you revert to the original encoding later, there is no "
+      "guarantee that the data can be restored to the original state.");
+    int reply = KMessageBox::warningContinueCancel( topLevelWidget(), msg,
+					   i18n("Encode"), i18n("&Encode"));
+    if( reply != KMessageBox::Continue )
     {
       // Restore correct menu setting
       mHexView->reportEncoding();
