@@ -18,16 +18,16 @@
  *
  */
 
-#include <iostream.h>
+#include <iostream>
 
 #include <qclipboard.h>
-#include <qdragobject.h>
-#include <qkeycode.h>
+#include <qdrawutil.h>
+
 
-#include <kapp.h>
 #include <kglobalsettings.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <kdebug.h>
 
 #include "hexdrag.h"
 #include "hexerror.h"
@@ -35,14 +35,14 @@
 
 //
 // The usage of the WNorthWestGravity flag should make screen update
-// faster (less paintEvents). I have had to add update() some places 
-// to ensure proper redrawing. Undefine if something goes wrong 
+// faster (less paintEvents). I have had to add update() some places
+// to ensure proper redrawing. Undefine if something goes wrong
 // (i.e. not updated )
 //
 #define USE_NORTHWEST_GRAVITY 1
 
 //
-// I don't want to decide what is best: Drag starts when mouse is moved or 
+// I don't want to decide what is best: Drag starts when mouse is moved or
 // after a timeout.
 //
 #define USE_DRAG_MOVEMENT 1
@@ -142,7 +142,7 @@ void CDragManager::timerEvent( QTimerEvent *e )
       Window root, w;
       uint mask;
       int i;
-  
+
       root = RootWindow( x11Display(), x11Screen() );
       XQueryPointer( x11Display(), root, &w, &w, &i, &i, &i, &i, &mask );
       emit startDrag( mask & ShiftMask ? true : false );
@@ -173,11 +173,11 @@ void CDragManager::setupTimer( void )
 //
 // This widget will use the entire space of the parent widget
 //
-CHexViewWidget::CHexViewWidget( QWidget *parent, const char *name, 
+CHexViewWidget::CHexViewWidget( QWidget *parent, const char *name,
 				CHexBuffer *hexBuffer )
   : QFrame( parent, name,
 	    #ifdef USE_NORTHWEST_GRAVITY
-	    WNorthWestGravity
+	    Qt::WStaticContents
 	    #else
 	    0
 	    #endif
@@ -190,10 +190,10 @@ CHexViewWidget::CHexViewWidget( QWidget *parent, const char *name,
   // -------
   // I use the "CScrollBar" because sometimes (very seldom) when I
   // do a mHorzScroll->hide() the mHorzScroll->isVisible() remains true
-  // in updateView() for a short while. I need the correct visibility 
+  // in updateView() for a short while. I need the correct visibility
   // because I have to redraw the area - due to the "WNorthWestGravity" usage.
   //
-  // I tried to do a 
+  // I tried to do a
   // "while( mHorzScroll->isVisible() ) { mHorzScroll->hide(); }"
   // but then the loop never ended. The "CScrollBar" emits a "hidden()"
   // signal whenever is receives a QHideEvent.
@@ -253,7 +253,7 @@ CHexViewWidget::~CHexViewWidget( void )
 }
 
 
-int CHexViewWidget::readFile( QFile &file, const QString &url, CProgress &p ) 
+int CHexViewWidget::readFile( QFile &file, const QString &url, CProgress &p )
 {
   int errCode = mHexBuffer->readFile( file, url, p );
   if( errCode != Err_Success )
@@ -266,7 +266,7 @@ int CHexViewWidget::readFile( QFile &file, const QString &url, CProgress &p )
 }
 
 
-int CHexViewWidget::insertFile( QFile &file, CProgress &p ) 
+int CHexViewWidget::insertFile( QFile &file, CProgress &p )
 {
   int errCode = mHexBuffer->insertFile( file, p );
   if( errCode != Err_Success )
@@ -296,7 +296,7 @@ int CHexViewWidget::newFile( const QString &url )
 }
 
 
-int CHexViewWidget::writeFile( QFile &file, CProgress &p ) 
+int CHexViewWidget::writeFile( QFile &file, CProgress &p )
 {
   int errCode = mHexBuffer->writeFile( file, p );
   if( errCode == Err_Success )
@@ -307,7 +307,7 @@ int CHexViewWidget::writeFile( QFile &file, CProgress &p )
 }
 
 
-void CHexViewWidget::closeFile( void ) 
+void CHexViewWidget::closeFile( void )
 {
   emit fileClosed( mHexBuffer->url() );
   mHexBuffer->closeFile();
@@ -386,8 +386,8 @@ void CHexViewWidget::setBuffer( CHexBuffer *hexBuffer )
 
 
 
-void CHexViewWidget::changeXPos( int p ) 
-{ 
+void CHexViewWidget::changeXPos( int p )
+{
   int dx = startX() - p;
   setStartX(p);
 
@@ -404,18 +404,18 @@ void CHexViewWidget::changeXPos( int p )
   //
   // If the start position has become 0, then update the view. This
   // will remove the scrollbar (if it is visible) if the textarea width
-  // is wider than the text. The scrollbar will then disappear under the 
+  // is wider than the text. The scrollbar will then disappear under the
   // mouse pointer.
   //
-  if( startX() == 0 ) 
-  { 
-    updateView( false, false ); 
+  if( startX() == 0 )
+  {
+    updateView( false, false );
   }
 
 }
 
 
-void CHexViewWidget::changeYPos( int p ) 
+void CHexViewWidget::changeYPos( int p )
 {
   int dy  = startY() - p;
   setStartY(p);
@@ -432,7 +432,7 @@ void CHexViewWidget::changeYPos( int p )
   //
   // If the start position has become 0, then update the view. This
   // will remove the scrollbar (if it is visible) if the textarea height
-  // is taller than the text. The scrollbar will then disappear under the 
+  // is taller than the text. The scrollbar will then disappear under the
   // mouse pointer.
   //
   if( startY() == 0 )
@@ -480,7 +480,7 @@ void CHexViewWidget::insert( SInsertData &id )
     mHexBuffer->cursorGoto( id.offset, 7 );
   }
   SCursorConfig cc;
-  updateCursor( cc, true ); 
+  updateCursor( cc, true );
 
   if( id.size == 0 )
   {
@@ -578,14 +578,14 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
 
   for( uint i=0; i < 2; i++ )
   {
-    editWidth  = width()  - f2; // Total available width 
-    editHeight = height() - f2; // Total available height 
+    editWidth  = width()  - f2; // Total available width
+    editHeight = height() - f2; // Total available height
     int textWidth  = dataWidth();
     int textHeight = mHexBuffer->totalHeight();
 
     //
     // This will move the start position of the horizontal scrollbar
-    // to the left (if possible) if the text width is smaller than the 
+    // to the left (if possible) if the text width is smaller than the
     // edit width.
     //
     if( startX() > 0 )
@@ -593,7 +593,7 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
       int size = mVertScroll->isVisible() == true ? mScrollBarSize : 0;
       if( startX() + editWidth - size > textWidth )
       {
-	int position = textWidth - editWidth + size; 
+	int position = textWidth - editWidth + size;
 	setStartX( position > 0 ? position : 0 );
 	#ifdef USE_NORTHWEST_GRAVITY
 	redraw = true;
@@ -603,15 +603,15 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
 
     int tooMuchX = textWidth - editWidth;
     bool horzScrollbarVisible = startX() > 0 || tooMuchX > 0 ? true : false;
-    if( horzScrollbarVisible == true ) 
-    { 
-      editHeight -= mScrollBarSize; 
+    if( horzScrollbarVisible == true )
+    {
+      editHeight -= mScrollBarSize;
     }
 
 
     //
     // This will move the start position of the vertical scrollbar
-    // to the top (if possible) if the text height is smaller than the 
+    // to the top (if possible) if the text height is smaller than the
     // edit height.
     //
     if( startY() > 0 )
@@ -629,23 +629,23 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
     int tooMuchY  = textHeight - editHeight;
     int startLine = startY() / textHeight;
 
-    if( startLine > 0 || tooMuchY > 0 ) 
+    if( startLine > 0 || tooMuchY > 0 )
     {
       editWidth -= mScrollBarSize;
       tooMuchX += mScrollBarSize;
-      if( horzScrollbarVisible == false && tooMuchX > 0 ) 
+      if( horzScrollbarVisible == false && tooMuchX > 0 )
       {
 	// Horizontal scrollbar will be visible after all.
 	editHeight -= mScrollBarSize;
 	tooMuchY += mScrollBarSize;
       }
     }
-    
+
     if( tooMuchX < startX() ) { tooMuchX = startX(); }
     if( tooMuchY < startY() ) { tooMuchY = startY(); }
 
     scrollBarCount = 0;
-    if( tooMuchX > 0 && documentPresent() == true ) 
+    if( tooMuchX > 0 && documentPresent() == true )
     {
       mHorzScroll->blockSignals( true );
       mHorzScroll->setGeometry( 0, editHeight+f2, editWidth+f2,mScrollBarSize);
@@ -655,13 +655,13 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
       mHorzScroll->blockSignals( false );
       if( mHorzScroll->isVisible() == false ) { mHorzScroll->show(); }
       scrollBarCount ++;
-    } 
-    else 
+    }
+    else
     {
-      if( mHorzScroll->isVisible() == true ) { mHorzScroll->hide(); } 
+      if( mHorzScroll->isVisible() == true ) { mHorzScroll->hide(); }
     }
 
-    if( tooMuchY > 0 && documentPresent() == true ) 
+    if( tooMuchY > 0 && documentPresent() == true )
     {
       mVertScroll->blockSignals( true );
       mVertScroll->setGeometry( editWidth+f2, 0, mScrollBarSize,editHeight+f2);
@@ -672,12 +672,12 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
       mVertScroll->blockSignals( false );
       if( mVertScroll->isVisible() == false ) { mVertScroll->show(); }
       scrollBarCount ++;
-    } 
-    else 
+    }
+    else
     {
       if( mVertScroll->isVisible() == true ) { mVertScroll->hide(); }
     }
-    
+
     if( fixCursor == true )
     {
       int position = mHexBuffer->cursorFixedPosition( startY(), height() );
@@ -694,7 +694,7 @@ void CHexViewWidget::updateView( bool redraw, bool fixCursor )
 
   if( scrollBarCount == 2 )
   {
-    mCorner->setGeometry( editWidth+f2, editHeight+f2, mScrollBarSize, 
+    mCorner->setGeometry( editWidth+f2, editHeight+f2, mScrollBarSize,
 			  mScrollBarSize );
     mCorner->show();
   }
@@ -741,17 +741,17 @@ void CHexViewWidget::setInputMode( SDisplayInputMode &input )
 }
 
 
-void CHexViewWidget::setCursor( const SDisplayCursor &cursor, 
+void CHexViewWidget::setCursor( const SDisplayCursor &cursor,
                                 bool /*updateDisplay*/ )
 {
   mCursor = cursor;
-  mHexBuffer->setCursorShapeModifier( cursor.alwaysBlockShape, 
+  mHexBuffer->setCursorShapeModifier( cursor.alwaysBlockShape,
 				      cursor.thickInsertShape );
   setupCursorTimer();
   redrawFromOffset( mHexBuffer->cursorOffset(), false );
 }
 
-void CHexViewWidget::setColor( const SDisplayColor &color, 
+void CHexViewWidget::setColor( const SDisplayColor &color,
 			       bool updateDisplay )
 {
   mColor = color;
@@ -762,7 +762,7 @@ void CHexViewWidget::setColor( const SDisplayColor &color,
   }
 }
 
-void CHexViewWidget::setFont( const SDisplayFontInfo &fontInfo, 
+void CHexViewWidget::setFont( const SDisplayFontInfo &fontInfo,
 			      bool updateDisplay )
 {
   mFontInfo = fontInfo;
@@ -781,18 +781,18 @@ void CHexViewWidget::setMisc( SDisplayMisc &misc )
   mMisc = misc;
   mHexBuffer->setUndoLevel( misc.undoLevel );
   mHexBuffer->setSoundState( misc.inputSound, misc.fatalSound );
-  mHexBuffer->setBookmarkVisibility( misc.bookmarkOffsetColumn, 
+  mHexBuffer->setBookmarkVisibility( misc.bookmarkOffsetColumn,
 				     misc.bookmarkEditor );
   if( mHexBuffer->documentPresent() == true )
   {
     QWidget::update();
   }
-}  
+}
 
 
 void CHexViewWidget::setInsertMode( bool insertMode )
 {
-  setEditMode( insertMode == true ? CHexBuffer::EditInsert : 
+  setEditMode( insertMode == true ? CHexBuffer::EditInsert :
 	       CHexBuffer::EditReplace );
 }
 
@@ -860,9 +860,9 @@ int CHexViewWidget::findWrap( SSearchControl &sc )
 int CHexViewWidget::replaceAll( SSearchControl &sc, bool init )
 {
   int errCode = mHexBuffer->replaceAll( sc, init );
-  if( errCode == Err_Success ) 
-  { 
-    updateWindow( true, false ); 
+  if( errCode == Err_Success )
+  {
+    updateWindow( true, false );
     emit dataChanged();
   }
   return( errCode );
@@ -871,9 +871,9 @@ int CHexViewWidget::replaceAll( SSearchControl &sc, bool init )
 int CHexViewWidget::replaceMarked( SSearchControl &sc )
 {
   int errCode = mHexBuffer->replaceMarked( sc );
-  if( errCode == Err_Success ) 
-  { 
-    updateWindow( true, false ); 
+  if( errCode == Err_Success )
+  {
+    updateWindow( true, false );
     emit dataChanged();
   }
   return( errCode );
@@ -893,7 +893,7 @@ int CHexViewWidget::collectStatistic( SStatisticControl &sc, CProgress &p )
 }
 
 
-void CHexViewWidget::gotoOffset( uint offset, uint bit, bool fromCursor, 
+void CHexViewWidget::gotoOffset( uint offset, uint bit, bool fromCursor,
 				 bool forward )
 {
   bool reverse = forward == true ? false : true;
@@ -975,8 +975,8 @@ void CHexViewWidget::copy( void )
   //
   // Note: Do no give the CHexDrag a parent != 0. The clipboard
   // owns the current dragdata and will destroy it on exit or
-  // when it receives a new object. If the CHexDrag has a parent 
-  // != 0, the CHexDrag object will be destroyed when the parent 
+  // when it receives a new object. If the CHexDrag has a parent
+  // != 0, the CHexDrag object will be destroyed when the parent
   // is destroyed. We will then have a double destroy situation
   // when the app. is closed (=> segfault).
   //
@@ -1016,7 +1016,7 @@ void CHexViewWidget::paste( void )
     }
 
     QString text;
-    if( QTextDrag::decode( data, text ) == true ) 
+    if( QTextDrag::decode( data, text ) == true )
     {
       QByteArray buf;
       if( mClipConvert.decode( buf, text ) == true )
@@ -1051,7 +1051,7 @@ void CHexViewWidget::undo( void )
   {
     return;
   }
- 
+
   updateWindow( true, true );
   emit dataChanged();
 }
@@ -1082,7 +1082,7 @@ void CHexViewWidget::addBookmark( int position )
     return;
   }
   redrawFromOffset( mHexBuffer->cursorOffset(), false );
- 
+
   emit bookmarkChanged( mHexBuffer->bookmarkList() );
 }
 
@@ -1090,7 +1090,7 @@ void CHexViewWidget::addBookmark( int position )
 
 int CHexViewWidget::bookmarkMenu( const QString &title )
 {
-  QList<SCursorOffset> &list = mHexBuffer->bookmarkList();
+  QPtrList<SCursorOffset> &list = mHexBuffer->bookmarkList();
   if( list.count() == 0 )
   {
     return( -1 );
@@ -1102,8 +1102,8 @@ int CHexViewWidget::bookmarkMenu( const QString &title )
   {
     const SCursorOffset *p = list.at( i );
     if( p == 0 ) { continue; }
-    
-    text.sprintf("%04X:%04X", p->offset>>16, p->offset&0x0000FFFF );   
+
+    text.sprintf("%04X:%04X", p->offset>>16, p->offset&0x0000FFFF );
     text.prepend( QString("[%1] %2: ").arg(i+1).arg(i18n("Offset")) );
     popup->insertItem( text, i );
   }
@@ -1113,7 +1113,7 @@ int CHexViewWidget::bookmarkMenu( const QString &title )
   int position = popup->exec( mapToGlobal(center) );
   delete popup;
 
-  return( position );  
+  return( position );
 }
 
 
@@ -1135,7 +1135,7 @@ void CHexViewWidget::removeBookmark( bool all )
     {
       return;
     }
-    
+
     const SCursorOffset *p = mHexBuffer->bookmarkList().at(position);
     uint offset = p ? p->offset : 0;
 
@@ -1154,7 +1154,7 @@ void CHexViewWidget::removeBookmark( bool all )
 
 void CHexViewWidget::replaceBookmark( void )
 {
-  QList<SCursorOffset> &list = mHexBuffer->bookmarkList();
+  QPtrList<SCursorOffset> &list = mHexBuffer->bookmarkList();
   if( list.count() == 0 )
   {
     return;
@@ -1171,7 +1171,7 @@ void CHexViewWidget::replaceBookmark( void )
 
 void CHexViewWidget::gotoBookmark( uint position )
 {
-  QList<SCursorOffset> &list = mHexBuffer->bookmarkList();
+  QPtrList<SCursorOffset> &list = mHexBuffer->bookmarkList();
   if( position >= list.count() )
   {
     return;
@@ -1191,7 +1191,7 @@ void CHexViewWidget::gotoBookmark( uint position )
 
 void CHexViewWidget::gotoNextBookmark( bool next )
 {
-  QList<SCursorOffset> &list = mHexBuffer->bookmarkList();
+  QPtrList<SCursorOffset> &list = mHexBuffer->bookmarkList();
   uint offset = mHexBuffer->cursorOffset();
   uint diff   = ~0;
 
@@ -1292,11 +1292,11 @@ void CHexViewWidget::benchmark( void )
 
   uint area  = width() * height();
   uint last = (t2.tv_sec-t1.tv_sec) * 1000000 + (t2.tv_usec - t1.tv_usec);
-  
-  debug( "Duration:      %f", (float)last/ 1000000.0 );
-  debug( "Duration/loop: %f", (float)last/ (1000000.0*(float)loop) );
-  debug( "Area:          %d", area );
-  debug( "Loop:          %d", loop );
+
+  kdDebug() << "Duration: " << (float)last/ 1000000.0 << endl;
+  kdDebug() << "Duration/loop: " << (float)last/ (1000000.0*(float)loop) << endl;
+  kdDebug() << "Area: " << area << endl;
+  kdDebug() << "Loop: " << loop << endl;
 }
 
 
@@ -1360,7 +1360,7 @@ void CHexViewWidget::updateFrameSize( void )
   if( w < 0 ) { w = 0; }
   int h = height() - (mHorzScroll->isVisible() ? mScrollBarSize : 0);
   if( h < 0 ) { h = 0; }
-  
+
   setFrameRect( QRect(0,0,w,h) );
 }
 
@@ -1383,7 +1383,7 @@ void CHexViewWidget::drawFrame( QPainter *p )
   // I want to display the frame with a custom color whenever the widget
   // accepts a drop. The setPalette() function causes quite a bit of flicker
   // in the scrollbars (even when PropagationMode is NoChildren), so I
-  // draw the frame manually when it can accept a drop. Note that the 
+  // draw the frame manually when it can accept a drop. Note that the
   // code below is for the frame shape "QFrame::WinPanel|QFrame::Plain"
   //
   if( mDropHighlight == true )
@@ -1398,7 +1398,7 @@ void CHexViewWidget::drawFrame( QPainter *p )
 
 
 
-void CHexViewWidget::keyPressEvent( QKeyEvent *e )  
+void CHexViewWidget::keyPressEvent( QKeyEvent *e )
 {
   SCursorConfig cc;
   cc.state = e->state();
@@ -1442,7 +1442,7 @@ void CHexViewWidget::keyPressEvent( QKeyEvent *e )
     }
   }
 
-  if( e->state() & AltButton ) 
+  if( e->state() & AltButton )
   {
     if( e->key() == Key_Left || e->key() == Key_Right )
     {
@@ -1461,12 +1461,12 @@ void CHexViewWidget::keyPressEvent( QKeyEvent *e )
     return;
   }
 
-  switch ( e->key() ) 
+  switch ( e->key() )
   {
     case Key_Left:
       cursorLeft( cc );
     break;
-    
+
     case Key_Right:
       cursorRight( cc );
     break;
@@ -1482,7 +1482,7 @@ void CHexViewWidget::keyPressEvent( QKeyEvent *e )
     case Key_Home:
       cursorHome( cc );
     break;
-    
+
     case Key_End:
       cursorEnd( cc );
     break;
@@ -1524,9 +1524,9 @@ void CHexViewWidget::keyReleaseEvent( QKeyEvent *e )
   if( e->state() & ShiftButton && shiftButtonState() == false )
   {
     //
-    // The shift button was pressed when event was triggered, but is 
-    // now released. I use this as a sign to copy selected data to the 
-    // clipboard. The shiftButtonState() uses X-lib functions so have a 
+    // The shift button was pressed when event was triggered, but is
+    // now released. I use this as a sign to copy selected data to the
+    // clipboard. The shiftButtonState() uses X-lib functions so have a
     // look in the headerfile (inlined method) if you want to remove
     // this dependency.
     //
@@ -1535,7 +1535,7 @@ void CHexViewWidget::keyReleaseEvent( QKeyEvent *e )
 }
 
 
-void CHexViewWidget::mousePressEvent( QMouseEvent *e ) 
+void CHexViewWidget::mousePressEvent( QMouseEvent *e )
 {
   //
   // The RMB popup menu is managed by the KContextMenuManager
@@ -1545,7 +1545,7 @@ void CHexViewWidget::mousePressEvent( QMouseEvent *e )
   {
     if( e->state() & ControlButton )
     {
-      if( KContextMenuManager::showOnButtonPress() == true 
+      if( KContextMenuManager::showOnButtonPress() == true
 	  && mDocumentMenu != 0 )
       {
 	mDocumentMenu->popup( e->globalPos() );
@@ -1564,9 +1564,9 @@ void CHexViewWidget::mousePressEvent( QMouseEvent *e )
 
 }
 
-void CHexViewWidget::mouseMoveEvent( QMouseEvent *e ) 
+void CHexViewWidget::mouseMoveEvent( QMouseEvent *e )
 {
-  if( e->state() & LeftButton ) 
+  if( e->state() & LeftButton )
   {
     if( mDragManager->start( e ) == false )
     {
@@ -1576,17 +1576,17 @@ void CHexViewWidget::mouseMoveEvent( QMouseEvent *e )
   }
 }
 
-void CHexViewWidget::mouseReleaseEvent( QMouseEvent *e ) 
+void CHexViewWidget::mouseReleaseEvent( QMouseEvent *e )
 {
   //
   // The RMB popup menu is managed by the KContextMenuManager
   //
 
-  if( e->button() == LeftButton ) 
+  if( e->button() == LeftButton )
   {
     if( e->state() & ControlButton )
     {
-      if( KContextMenuManager::showOnButtonPress() == false 
+      if( KContextMenuManager::showOnButtonPress() == false
 	  && mDocumentMenu != 0 )
       {
 	mDocumentMenu->popup( e->globalPos() );
@@ -1642,9 +1642,9 @@ void CHexViewWidget::dragLeaveEvent( QDragLeaveEvent * )
 void CHexViewWidget::dragMoveEvent( QDragMoveEvent *e )
 {
   //
-  // Move the cursor if we are dragging (readable) text or binary 
-  // data. Note: the QTextDrag::canDecode() will return true if we 
-  // are dragging a file so we have to test for QUriDrag::canDecode() 
+  // Move the cursor if we are dragging (readable) text or binary
+  // data. Note: the QTextDrag::canDecode() will return true if we
+  // are dragging a file so we have to test for QUriDrag::canDecode()
   // first.
   //
 
@@ -1687,14 +1687,14 @@ void CHexViewWidget::dropEvent( QDropEvent *e )
   }
 
   QByteArray buf;
-  if( CHexDrag::decode( &m, buf ) == true ) 
+  if( CHexDrag::decode( &m, buf ) == true )
   {
     insert( buf );
     return;
   }
 
   QString text;
-  if( QTextDrag::decode( &m, text ) == true ) 
+  if( QTextDrag::decode( &m, text ) == true )
   {
     bool success = mClipConvert.decode( buf, text );
     if( success == true )
@@ -1707,7 +1707,7 @@ void CHexViewWidget::dropEvent( QDropEvent *e )
 }
 
 
-void CHexViewWidget::showEvent( QShowEvent * )  
+void CHexViewWidget::showEvent( QShowEvent * )
 {
   // Currently we do nothing here.
 }
@@ -1949,16 +1949,16 @@ void CHexViewWidget::paintText( const QRect &rect, bool expand )
     #endif
   }
 
-  if( contentsRect().contains( r ) == false ) 
+  if( contentsRect().contains( r ) == false )
   {
     paintFrame();
     if( r.left() < frameWidth() ) { r.setLeft( frameWidth() ); }
     if( r.top() < frameWidth() ) { r.setTop( frameWidth() ); }
   }
 
-  int maxX = width() - frameWidth() - 1 - 
+  int maxX = width() - frameWidth() - 1 -
     (mVertScroll->isVisible() ? mScrollBarSize : 0);
-  int maxY = height() - frameWidth() - 1 - 
+  int maxY = height() - frameWidth() - 1 -
     (mHorzScroll->isVisible() ? mScrollBarSize : 0);
 
   if( r.right() > maxX ) { r.setRight( maxX ); }
@@ -2054,14 +2054,14 @@ void CHexViewWidget::paintCursor( int cursorMode )
 
 
 
-void CHexViewWidget::updateCursor( SCursorConfig &cc, bool always, 
+void CHexViewWidget::updateCursor( SCursorConfig &cc, bool always,
 				   bool touchSelection )
 {
   if( mHexBuffer->cursorChanged() == false && always == false )
   {
     return;
   }
-  
+
   //
   // Make blinking (and perhaps invisible) cursor visible
   //
@@ -2079,9 +2079,9 @@ void CHexViewWidget::updateCursor( SCursorConfig &cc, bool always,
   if( cc.controlButton() == true )
   {
     //
-    // The cursor should stay fixed (if possible) in the window while 
-    // the text is scrolled (e.g., PageUp/Down behavior). The position 
-    // of the vertical scrollbar must change just as much as the cursor 
+    // The cursor should stay fixed (if possible) in the window while
+    // the text is scrolled (e.g., PageUp/Down behavior). The position
+    // of the vertical scrollbar must change just as much as the cursor
     // has changed in the vertical direction.
     //
     h  = frameWidth()*2;
@@ -2090,7 +2090,7 @@ void CHexViewWidget::updateCursor( SCursorConfig &cc, bool always,
     changeYPos( position );
   }
   else
-  { 
+  {
     h  = frameWidth()*2;
     h += mHorzScroll->isVisible() == false ? 0 : mScrollBarSize;
     position = mHexBuffer->cursorChangePosition( startY(), height()-h );
@@ -2204,7 +2204,7 @@ void CHexViewWidget::cursorPageUp( SCursorConfig &cc )
 void CHexViewWidget::cursorInsert( SCursorConfig &/*cc*/ )
 {
   // Toggle mode
-  setEditMode( mEditMode == CHexBuffer::EditInsert ? 
+  setEditMode( mEditMode == CHexBuffer::EditInsert ?
 	       CHexBuffer::EditReplace : CHexBuffer::EditInsert );
 }
 
@@ -2242,7 +2242,7 @@ void CHexViewWidget::cursorBackspace( SCursorConfig &/*cc*/ )
 
 void CHexViewWidget::cursorInput( QChar c )
 {
-  uint cursorLine = mHexBuffer->cursorLine();  
+  uint cursorLine = mHexBuffer->cursorLine();
   bool success = mHexBuffer->inputAtCursor( c );
   if( success == false )
   {
@@ -2257,7 +2257,7 @@ void CHexViewWidget::cursorInput( QChar c )
 void CHexViewWidget::setEditMode( CHexBuffer::EEditMode mode )
 {
   mEditMode = mode;
-  mHexBuffer->setEditMode( mEditMode, mCursor.alwaysBlockShape, 
+  mHexBuffer->setEditMode( mEditMode, mCursor.alwaysBlockShape,
 			   mCursor.thickInsertShape );
   setupCursorTimer();
 
@@ -2290,3 +2290,4 @@ void CHexViewWidget::setDropHighlight( bool dropHighlight )
 
 
 
+#include "hexviewwidget.moc"
