@@ -19,10 +19,9 @@
  */
 
 
+#include <stdlib.h>
 
-#include <iostream.h>
-#include <unistd.h>
-
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -50,12 +49,12 @@ int main( int argc, char **argv )
   KAboutData aboutData("khexedit", I18N_NOOP("KHexEdit"),
     version, description, KAboutData::License_GPL,
     "(c) 1999-2000, Espen Sand",
-    "This is a work in progress. If you\n\n"
+    I18N_NOOP("This is a work in progress. If you\n\n"
     "1. have a suggestion for improvement\n"
     "2. have found a bug\n"
     "3. want to contribute with something\n"
     "4. just want to tell me how nice or useful khexedit is\n\n"
-    "then feel free to send me a mail." );
+    "then feel free to send me a mail.") );
   aboutData.addAuthor("Espen Sand",0, "espensa@online.no", 
 		      "http://home.sol.no/~espensa/khexedit/" );
   KCmdLineArgs::init( argc, argv, &aboutData );
@@ -72,7 +71,7 @@ int main( int argc, char **argv )
     KHexEdit *hexEdit = new KHexEdit;
     if( hexEdit == 0 )
     {
-      cerr << "Unable to start - Memory exhausted" << endl;
+      std::cerr << "Unable to start - Memory exhausted" << std::endl;
       return( 1 );
     }
 
