@@ -18,13 +18,12 @@
  *
  */
 
+#include <limits.h>
 
 #include <qvbox.h>
 #include <qvbuttongroup.h>
 #include <qpainter.h>
 
-#include <values.h>
-
 #include <qcheckbox.h>
 #include <qlayout.h>
 #include <qlabel.h>
@@ -486,7 +485,7 @@ void COptionDialog::setupMiscPage( void )
 
   mMisc.thresholdSpin = new QSpinBox( page );
   mMisc.thresholdSpin->setMinimumWidth( fontMetrics().width("M") * 10 );
-  mMisc.thresholdSpin->setRange( 5, MAXINT );
+  mMisc.thresholdSpin->setRange( 5, INT_MAX );
   mMisc.thresholdSpin->setSteps( 5, 5 );
   mMisc.thresholdSpin->setValue( 5 );
 
