@@ -28,7 +28,7 @@
 #include <qlayout.h>
 #include <qdatetime.h>
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstringlist.h>
 #include <qdialog.h>
 #include <qlineedit.h>
@@ -49,8 +49,8 @@ class QTextStream;
 
 class TextEntry
 {
-  friend KJotsMain;
-  friend SubjList;
+  friend class KJotsMain;
+  friend class SubjList;
 public:
   TextEntry() {}
   virtual ~TextEntry() {}
@@ -125,7 +125,7 @@ public:
 signals:
   void entryMoved(int);
   void entryChanged(int);
-  void folderChanged(QList<TextEntry> *);
+  void folderChanged(QPtrList<TextEntry> *);
 
 public slots:
   void saveFolder();
@@ -151,12 +151,13 @@ protected slots:
   void moveFocus();
   void configureKeys();
   void copySelection();
-
+  void insertDate();
   void updateMenu();
 
   void slotSearch();
   void slotRepeatSearch();
   void slotReplace();
+  void slotQuit();
 
 protected:
   int readFile(QString name);
@@ -168,23 +169,18 @@ protected:
   QGridLayout   *bg_top_layout;
   KAccel        *keys;
 
-  QList<TextEntry> entrylist;
+  QPtrList<TextEntry> entrylist;
   int              current;
   bool             folderOpen;
   QString          current_folder_name;
   QStringList         folder_list;
   QStringList         hotlist;
-  QList<QPushButton> button_list;
-  QPopupMenu      *folders;
-  QFont            button_font;
+  QPtrList<QPushButton> button_list;
+  QPopupMenu      *folders_menu;
   int              unique_id;
   SubjList        *subj_list;
   ConfigureDialog *mOptionDialog;
 
-  //KToolBar        *toolbar;
-  QFrame          *f_text;
-  QFrame          *f_labels;
-  QFrame          *f_main;
   MyButtonGroup   *bg_top;
   QScrollBar      *s_bar;
   KEdit           *me_text;
@@ -192,16 +188,8 @@ protected:
   QLineEdit       *le_subject;
 
   // save id's for updateMenu()
-  int id_f_save_book;
   int id_f_save_book_ascii;
   int id_f_save_page_ascii;
-  int id_f_del_book;
-
-  int id_e_cut;
-  int id_e_copy;
-  int id_e_paste;
-  int id_e_new;
-  int id_e_del;
 
   int id_fav_add;
   int id_fav_del;
