@@ -21,7 +21,7 @@
 
 
 #include "cpopmenu.h"
-#include "qapplication.h"
+#include <qcursor.h>
 
 /*****************************************************************************
   CPopupMenu member functions
@@ -30,7 +30,7 @@
 CPopupMenu::CPopupMenu( QWidget *parent, const char *name )
     : QPopupMenu( parent, name )
 {
-    initMetaObject();
+//    initMetaObject();
     setMouseTracking(TRUE);
 }
 
@@ -68,3 +68,4 @@ void CPopupMenu::setActItem( int it)
   actItem = it;
 }
 
+#include "cpopmenu.moc"
