@@ -25,11 +25,8 @@
 #include "../config.h"
 #endif
 
-#include <qapplication.h>
-#include <qdir.h>
-#include <qfileinfo.h>
-
-#include <kapp.h>
+#include <stdlib.h>
+#include <kuniqueapplication.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
@@ -40,7 +37,7 @@
 
 
 static const char *description = 
-	I18N_NOOP("KDE Note take utility");
+	I18N_NOOP("KDE Note taking utility");
 
 static const char *version = "v0.4"; 
 
@@ -56,11 +53,19 @@ int main( int argc, char **argv )
 {
   KAboutData aboutData( "kjots", I18N_NOOP("KJots"),
     version, description, KAboutData::License_GPL,
-    "(c) 1997, Christoph Neerfeld");
+    "(c) 1997-2002, Christoph Neerfeld");
   aboutData.addAuthor("Christoph Neerfeld",0, "chris@kde.org");
-  KCmdLineArgs::init( argc, argv, &aboutData );
-
-  KApplication a;
+  aboutData.addAuthor("Aaron J. Seigo", 0, "aseigo@olympusproject.org");
+  KCmdLineArgs::init(argc, argv, &aboutData);
+  KUniqueApplication::addCmdLineOptions();
+  
+  if (!KUniqueApplication::start()) 
+  {
+     fprintf(stderr, "kjots is already running!\n");
+     exit(0);
+  }  
+  
+  KUniqueApplication a;
 
   QString temp1, temp2;
   KConfig *config = a.config();
