@@ -20,9 +20,8 @@
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qlineedit.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kconfig.h>
 #include <kfontdialog.h>
 #include <klocale.h>
@@ -37,7 +36,6 @@ ConfigureDialog::ConfigureDialog( QWidget *parent, char *name, bool modal )
 {
   setHelp( "kjots/index.html", QString::null );
  
-  setupURLPage();
   setupFontPage();
 
   readConfig();
@@ -48,46 +46,6 @@ ConfigureDialog::~ConfigureDialog( void )
 {
 }
 
-
-void ConfigureDialog::setupURLPage( void )
-{
-  QFrame *page = addPage( i18n("&URL") );
-  if( page == 0 ) { return; }
-
-  QGridLayout *grid = new QGridLayout( page, 5, 2, 0, spacingHint() );
-  
-  QLabel *label;
-  QString text;
-
-  text = i18n("Specify which command to execute");
-  label = new QLabel( text, page );
-  grid->addMultiCellWidget( label, 0, 0, 0, 1 );
-
-  text = i18n("For HTTP");
-  label = new QLabel( text, page );
-  grid->addWidget( label, 1, 0, AlignRight );
-  
-  text = i18n("For FTP");
-  label = new QLabel( text, page );
-  grid->addWidget( label, 2, 0, AlignRight );
-
-  mHttpInput = new QLineEdit( page );
-  mHttpInput->setMinimumWidth( fontMetrics().maxWidth()*20 );
-  grid->addWidget( mHttpInput, 1, 1 );
-
-  mFtpInput = new QLineEdit( page );
-  mFtpInput->setMinimumWidth( fontMetrics().maxWidth()*20 );
-  grid->addWidget( mFtpInput, 2, 1 );
-
-  text = i18n("(%u is replaced with the selected URL)");
-  label = new QLabel( text, page );
-  grid->addMultiCellWidget( label, 3, 3, 1, 1 );
-
-  grid->setRowStretch( 4, 10 );  
-}
-
-
-
 void ConfigureDialog::setupFontPage( void )
 {
   QFrame *page = addPage( i18n("Editor &Font") );
@@ -100,22 +58,16 @@ void ConfigureDialog::setupFontPage( void )
   topLayout->addWidget( mFontChooser );
 }
 
-
-
-
 void ConfigureDialog::readConfig( void )
 {
   KConfig &config = *kapp->config();
 
   config.setGroup("kjots");
-  mHttpInput->setText( config.readEntry("execHttp") );
-  mFtpInput->setText( config.readEntry("execFtp") );
 
   QFont font( config.readEntry("EFontFamily"), 
 	      config.readNumEntry("EFontSize"),
 	      config.readNumEntry("EFontWeight"), 
-	      config.readNumEntry("EFontItalic"),
-	      (QFont::CharSet) config.readNumEntry("EFontCharset") );
+	      config.readNumEntry("EFontItalic"));
   mFontChooser->setFont(font);
 }
 
@@ -124,17 +76,14 @@ void ConfigureDialog::writeConfig( void )
   KConfig &config = *kapp->config();
 
   config.setGroup("kjots");
-  config.writeEntry( "execHttp", mHttpInput->text() );
-  config.writeEntry( "execFtp", mFtpInput->text() );
   QFont font = mFontChooser->font();
   config.writeEntry("EFontFamily", font.family());
   config.writeEntry("EFontSize", font.pointSize());
   config.writeEntry("EFontWeight", font.weight());
   config.writeEntry("EFontItalic", font.italic());
-  config.writeEntry("EFontCharset", (int)font.charSet());
+//  config.writeEntry("EFontCharset", (int)font.charSet());
 }
 
-
 void ConfigureDialog::slotOk( void )
 {
   slotApply();
