@@ -6,7 +6,7 @@
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.h,v 1.6 2001/03/26 03:22:31 staikos Exp $
+ * $Id: daemondock.h,v 1.8 2002/02/26 20:54:52 staikos Exp $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -64,8 +64,12 @@ private slots:
   void slotResetAction(int id);
   void slotDisplayAction(int id);
 
+  void rootExited(KProcess *p);
+  void slotGoRoot(int id);
+  void slotQuit();
+
 private:
-  laptop_daemon *p;
+  laptop_daemon *pdaemon;
   QPixmap	pm;
   int	 	current_code;
   KPCMCIA       *_pcmcia;
