@@ -40,7 +40,6 @@
 //		
 //
 
-#include <qlabel.h>
 #include <klocale.h>
 #include <stdio.h>
 #include "portable.h"
@@ -98,6 +97,158 @@ apm_read(apm_info *ap)
 	return(0);
 }
 
+static const char * const batt_info[] = {
+	"/proc/acpi/battery/0/info",
+	"/proc/acpi/battery/1/info",
+	"/proc/acpi/battery/2/info",
+	"/proc/acpi/battery/3/info",
+};
+
+static const char * const batt_status[] = {
+	"/proc/acpi/battery/0/status",
+	"/proc/acpi/battery/1/status",
+	"/proc/acpi/battery/2/status",
+	"/proc/acpi/battery/3/status",
+};
+
+
+static unsigned char acpi_batt_ok[4];
+static unsigned char acpi_ac_ok;
+
+static int
+getint(char *s)
+{
+	int v = 0, sgn=1;
+
+	for (;;) {
+		if (*s == 0)
+			return(0);
+		if (*s == ':')
+			break;
+		s++;
+	}	
+	s++;
+	for (;;) {
+		if (*s == 0)
+			return(0);
+		if (*s != ' ' && *s != '\t')
+			break;
+		s++;
+	}
+	if (*s == '-') {
+		s++;
+		sgn = -1;
+	} else 
+	if (*s == '+')
+		s++;
+	while (*s >= '0' && *s <= '9') {
+		v = (v*10) + (*s-'0');
+		s++;
+	}
+	return(sgn*v);
+}
+
+//
+//	linux APCI doesn't return usefull stuff like how much TIME is left yet
+//		the 'rate' is not smoothed over time so it's faked out here
+//		it's not pretty and it's a quick estimate
+//
+//		for the moment we prefer APM
+//
+static int
+acpi_read(apm_info *ap)
+{
+   	FILE	*f;
+	int	v, i;
+	int rate, part, total; 
+	int ret = 1;
+	char buff[1024];
+	static int ratecount=0;
+	static int ratetotal=0;
+
+	part = 0;
+	total = 0;
+	rate = 0;
+	for (i = 0; i < 4; i++)
+	if (acpi_batt_ok[i]) {
+		int remaining = 0;
+		int caplow = 0;
+		int cap = 0;
+		int first=1;
+
+		f = fopen(batt_info[i], "r");
+again:
+		if (f == NULL) {
+			if (!first)
+				continue;
+			first = 0;
+			f = fopen(batt_status[i], "r");
+			goto again;
+		}
+		for (;;) {
+			if (fgets(buff, sizeof(buff), f) == NULL)
+				break;
+			if (strstr(buff, "Design Capacity Low:") != NULL) {
+				caplow = getint(buff);
+			} else
+			if (strstr(buff, "Present Rate:") != NULL) {
+				v = getint(buff);
+				if (v < 0)
+					v = 0;
+			} else
+			if (strstr(buff, "Last Full Capacity:") != NULL) {
+				cap = getint(buff);
+			} else
+			if (strstr(buff, "Remaining Capacity:") != NULL) {
+				remaining = getint(buff);
+			} 
+		}
+   		fclose(f);
+		if (first) {
+			first = 0;
+			f = fopen(batt_status[i], "r");
+			goto again;
+		}
+		ret = 0;
+		if (caplow < 0)
+			caplow = 0;
+		cap -= caplow;
+		if (cap < 0)
+			cap = 0;
+		remaining -= caplow;
+		if (remaining < 0)
+			remaining = 0;
+		total += cap;
+		part += remaining;
+	}
+	if (ratecount == 16) {	// about 5 mins with a 20 sec poll
+		ratecount /= 2;
+		ratetotal /= 2;
+	}
+	ratecount++;
+	ratetotal += v;
+	rate = ratetotal/ratecount;
+	ap->battery_percentage = (total==0?0:100*part/total);
+	//ap->battery_time = (rate==0||part==0?0 : part/rate);
+	ap->battery_time = -1;
+	ap->ac_line_status = 0;
+	ap->apm_flags = 0;
+	f = fopen("/proc/acpi/ac_adapter/0/status", "r");
+	if (f) {
+		for (;;) {
+			if (fgets(buff, sizeof(buff), f) == NULL)
+				break;
+			if (strstr(buff, "Status:") != NULL) {
+				if (strstr(buff, "on-line") != NULL) 
+					ap->ac_line_status |= 1;
+				break;
+			}
+		}
+		fclose(f);
+	}
+	return(ret);
+}
+
 static int apm_no_time;
 static apm_info apmx = {0,0,0,0};
 static int
@@ -107,19 +258,44 @@ has_apm()
         static int val;
         if (init)
                 return(val);
- 
         init = 1;
         val = 1;
         apm_no_time=0;
         if (apm_read(&apmx) || (apmx.apm_flags&0x20)) {
                 val = 0;
                 apm_no_time = 1;
-                                      
         } else {
                 apm_no_time = apmx.battery_time < 0;
         }
         return(val);
 }
+
+static int
+has_acpi()
+{
+	static int init = 0;
+	static int val;
+	int i;
+
+	if (init)
+		return(val);
+	init = 1;
+	val = 0;
+	if (::access("/proc/acpi/ac_adapter/0/status", R_OK) == 0)
+		acpi_ac_ok = 1;
+	for (i = 0; i < 4; i++) {
+		if (::access(batt_status[i], R_OK) == 0 ||
+		    ::access(batt_info[i], R_OK) == 0)
+			acpi_batt_ok[i] = 1;
+	}
+	if (acpi_ac_ok &&
+		(acpi_batt_ok[0] ||
+		 acpi_batt_ok[1] ||
+		 acpi_batt_ok[2] ||
+		 acpi_batt_ok[3]))
+		val = 1;
+	return(val);
+}
  
 static int
 apm_has_time()
@@ -132,13 +308,17 @@ apm_has_time()
 //
 int laptop_portable::has_power_management()
 {
-	return (::has_apm());
+	if (::has_apm())
+		return(1);
+	return (::has_acpi());
 }
 //
 //	returns 1 if the BIOS returns the time left in the battery rather than a % of full
 //
 int laptop_portable::has_battery_time()
 {
+	if (::has_acpi())
+		return(0);
 	return (::apm_has_time());
 }
 //
@@ -148,6 +328,8 @@ int laptop_portable::has_battery_time()
 int laptop_portable::has_suspend()
 {
 	struct stat s;
+	if (::has_acpi())
+		return(0);
         if (stat("/usr/bin/apm", &s) || !(getuid() == 0 || s.st_mode&S_ISUID)) 
 		return(0);
 	return(1);
@@ -159,6 +341,8 @@ int laptop_portable::has_suspend()
 int laptop_portable::has_standby()
 {
 	struct stat s;
+	if (::has_acpi())
+		return(0);
         if (stat("/usr/bin/apm", &s) || !(getuid() == 0 || s.st_mode&S_ISUID)) 
 		return(0);
 	return(1);
@@ -188,7 +372,12 @@ int laptop_portable::has_hibernation()
 
 QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
-	QLabel* explain = new QLabel(i18n("Your computer doesn't have the Linux APM (Advanced\nPower Management) software installed, or doesn't have\nthe APM kernel drivers installed - check out the Linux Laptop-HOWTO\ndocument for information how to install APM\nit is available at http://www.linuxdoc.org/HOWTO/Laptop-HOWTO.html"), parent);
+	if (access("/proc/acpi", F_OK) == 0) {	// probably has default kernel ACPI installed
+		QLabel* explain = new QLabel(i18n("Your computer seems to have a partial ACPI installation\nprobably ACPI was enabled, but some of the sub-options\nwere not enabled - you need to enable at least 'AC Adaptor'\nand 'Control Method Battery' and rebuild your kernel"), parent);
+      		explain->setMinimumSize(explain->sizeHint());       
+		return(explain);
+	}
+	QLabel* explain = new QLabel(i18n("Your computer doesn't have the Linux APM (Advanced\nPower Management) or ACPI software installed, or doesn't have\nthe APM kernel drivers installed - check out the Linux Laptop-HOWTO\ndocument for information how to install APM\nit is available at http://www.linuxdoc.org/HOWTO/Laptop-HOWTO.html"), parent);
       	explain->setMinimumSize(explain->sizeHint());       
 	return(explain);
 }
@@ -198,7 +387,17 @@ QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 //
 QLabel *laptop_portable::how_to_do_suspend_resume(QWidget *parent)
 {
- 	QLabel* note = new QLabel(i18n("\nIf you make /usr/bin/apm setuid then you will also\nbe able to choose 'suspend' and 'standby' in the\nabove dialog - check out the help button below to\nfind out how to do this"), parent);
+	if (::has_apm()) {
+ 		QLabel* note = new QLabel(i18n("\nIf you make /usr/bin/apm setuid then you will also\nbe able to choose 'suspend' and 'standby' in the\nabove dialog - check out the help button below to\nfind out how to do this"), parent);
+        	note->setMinimumSize(note->sizeHint()); 
+		return(note);
+	}
+	if (::has_acpi()) {
+ 		QLabel* note = new QLabel(i18n("\nCurrently ACPI suspend/standby is not supported"), parent);
+        	note->setMinimumSize(note->sizeHint()); 
+		return(note);
+	}
+ 	QLabel* note = new QLabel(i18n("\nYour system does not support suspend/standby"), parent);
         note->setMinimumSize(note->sizeHint()); 
 	return(note);
 }
@@ -208,7 +407,8 @@ static int present=0;
 static 
 void get_pcmcia_info()
 {
-      FILE *f = fopen("/var/run/stab", "r");
+      FILE *f = fopen("/var/lib/pcmcia/stab", "r");
+      if (!f) f = fopen("/var/run/stab", "r");
       if (f) {
 	char c, *cp;
 
@@ -317,7 +517,7 @@ struct power_result laptop_portable::poll_battery_state()
 	struct power_result p;
 
 	apm_info x = {0,0,0,0};
-        if (apm_read(&x) || (x.apm_flags&0x20)) {
+        if ((::has_acpi() ? ::acpi_read(&x) : ::apm_read(&x)) || (x.apm_flags&0x20)) {
                 p.powered = 0;
                 p.percentage=0;
                 p.time = 0;
@@ -709,7 +909,7 @@ int laptop_portable::has_hibernation()
 //
 QLabel *laptop_portable::no_power_management_explanation(QWidget *parent)
 {
-	QLabel* explain = new QLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels, if you want help porting these panels to work with it\nplease contact paul@taniwha.com"), parent);
+	QLabel* explain = new QLabel(i18n("Your computer or operating system is not supported by the current version of the\nKDE laptop control panels. If you want help porting these panels to work with it\nplease contact paul@taniwha.com."), parent);
       	explain->setMinimumSize(explain->sizeHint());       
 	return(explain);
 }
