@@ -1,7 +1,8 @@
 /*
- * pcmcia.h
+ * warning.h
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
+ * Copyright (c) 2002 Marc Mutz <mutz@kde.org>
  *
  * Requires the Qt widget libraries, available at no cost at
  * http://www.troll.no/
@@ -25,18 +26,14 @@
 #ifndef __WARNINGCONFIG_H__
 #define __WARNINGCONFIG_H__
 
-#include <qdialog.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qlcdnumber.h>
-#include <qradiobutton.h>
-#include <qbuttongroup.h>
-#include <qcheckbox.h>
-
-#include <kapp.h>
-#include <knuminput.h>
-
 #include <kcmodule.h>
+#include <qstring.h>
+
+class QWidget;
+class KConfig;
+class KURLRequester;
+class QCheckBox;
+class QSpinBox;
 
 class WarningConfig : public KCModule
 {
@@ -50,11 +47,6 @@ public:
 
   virtual QString quickHelp() const;
 
-public slots:
-  void enableRunCommand(bool);
-  void enablePlaySound(bool);
-  void browseRunCommand();
-  void browsePlaySound();         
 private slots:
   void configChanged();
     
@@ -63,9 +55,9 @@ private:
 
   KConfig *config;
  
-  QLineEdit *editRunCommand;
-  QLineEdit *editPlaySound;
-  QLineEdit* editLow;
+  KURLRequester* editRunCommand;
+  KURLRequester* editPlaySound;
+  QSpinBox* editLow;
  
   QCheckBox *checkRunCommand;
   QCheckBox *checkPlaySound;
@@ -73,13 +65,12 @@ private:
   QCheckBox *checkNotify;
   QCheckBox *checkSuspend;
   QCheckBox *checkStandby;
+  QCheckBox *checkHibernate;
  
-  QPushButton *buttonBrowsePlaySound;
-  QPushButton *buttonBrowseRunCommand;
- 
-  bool    apm, runcommand, playsound, beep, notify, do_suspend, do_standby;
-  QString runcommand_val, low_val, crit_val, sound_val;
-  int             have_time, type;        
+  bool    apm, runcommand, playsound, beep, notify, do_suspend, do_standby, do_hibernate;
+  QString runcommand_val, sound_val;
+  int     low_val;
+  int     have_time, type;
 
 };
 
