@@ -1,6 +1,6 @@
     /*
 
-    $Id: main.cpp,v 1.11 2000/01/30 02:40:08 charles Exp $
+    $Id: main.cpp,v 1.12 2001/10/13 01:06:31 mueller Exp $
 
     Requires the Qt widget libraries, available at no cost at 
     http://www.troll.no
@@ -31,7 +31,7 @@
 // QLayout based.
 //
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kcmdlineargs.h>
 #include <klocale.h>
 #include <kaboutdata.h>
