@@ -23,25 +23,21 @@
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qfile.h>
-#include <qfont.h>
-#include <qframe.h>
-#include <qgroupbox.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 #include <qradiobutton.h>
-#include <qtextstream.h>
 #include <qtimer.h>
 #include <qvbuttongroup.h> 
  
-#include <kapp.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <knumvalidator.h>
 
 #include "optiondialog.h"
 #include "version.h"
+#include <qpushbutton.h>
 
 #include "optiondialog.moc"
 
@@ -96,6 +92,7 @@ void OptionDialog::setupPaperPage( void )
   vlay1->addWidget( label );
 
   mPaper.copyEdit = new QLineEdit( page, "copyedit" );
+  mPaper.copyEdit->setValidator( new KIntValidator( 1,9999,mPaper.copyEdit ) );
   mPaper.copyEdit->setText( "1" );
   vlay1->addWidget( mPaper.copyEdit );
 
@@ -103,6 +100,8 @@ void OptionDialog::setupPaperPage( void )
   vlay1->addWidget( label );
 
   mPaper.linesEdit = new QLineEdit( page, "lineedit" );
+  mPaper.linesEdit->setValidator( new KIntValidator( 1,9999,mPaper.linesEdit ) );
+
   mPaper.linesEdit->setText( "66" );
   vlay1->addWidget( mPaper.linesEdit );
 
@@ -296,11 +295,15 @@ void OptionDialog::setupFontPage( void )
   label = new QLabel( i18n("Font:"), page );
   glay->addWidget( label, 2, 0, AlignRight );
   mFont.fontEdit = new QLineEdit( page, "font" );
+  mFont.fontEdit->setValidator( new KIntValidator( 1,9999,mFont.fontEdit ) );
+
   glay->addWidget( mFont.fontEdit, 2, 1 );
 
   label = new QLabel( i18n("Pitch:"), page );
   glay->addWidget( label, 3, 0, AlignRight );
   mFont.pitchEdit = new QLineEdit( page, "pitch" );
+  mFont.pitchEdit->setValidator( new KIntValidator( 1,9999,mFont.pitchEdit ) );
+
   glay->addWidget( mFont.pitchEdit, 3, 1 );
   label = new QLabel( i18n("cpi"), page );
   glay->addWidget( label, 3, 2 );
@@ -308,6 +311,8 @@ void OptionDialog::setupFontPage( void )
   label = new QLabel( i18n("Point Size:"), page );
   glay->addWidget( label, 4, 0, AlignRight );
   mFont.pointSizeEdit = new QLineEdit( page, "pointsize" );
+  mFont.pointSizeEdit->setValidator( new KIntValidator( 1,9999,mFont.pointSizeEdit ) );
+
   glay->addWidget( mFont.pointSizeEdit, 4, 1 );
   label = new QLabel( i18n("points"), page );
   glay->addWidget( label, 4, 2 );
