@@ -5,7 +5,7 @@
 
 
 #include <kdialogbase.h>
-class QScrollBar;
+class QSlider;
 class QLCDNumber;
 
 class ConfAutoUpdate : public KDialogBase
@@ -20,7 +20,7 @@ class ConfAutoUpdate : public KDialogBase
     int  getFrequency( void );
 
   private:
-    QScrollBar *mFrequencyScrollBar;
+    QSlider *mFrequencySlider;
     QLCDNumber *mFrequencyLCD;
 };
 
