@@ -2,7 +2,8 @@
 #ifndef kheader_included
 #define kheader_included
 
-#include "qframe.h"
+#include <qframe.h>
+#include <qcursor.h>
 
 class KHeaderItem;
 
@@ -22,7 +23,8 @@ public:
   int numHeaders();
   void setHeaderSize( int header, int width );
   int  getHeaderSize( int header );
-  void setHeaderLabel( int header, const char *text, int align = AlignCenter );
+  void setHeaderLabel( int header, const QString &text,
+		       int align = AlignCenter );
   void setHeaderFlags( int header, int flags );
   void setGeometry( int x, int y, int w, int h );
   void resize( int w, int h );
@@ -46,7 +48,7 @@ private:
   bool eventFilter( QObject *, QEvent * );
   void adjustHeaderSize( int start, int delta );
 
-  QArray<KHeaderItem*> labels;
+  QMemArray<KHeaderItem*> labels;
   int divider;
   int divstart;
   int m_offset;
