@@ -21,43 +21,37 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
-#ifndef klpq_included
-#define klpq_included
+#ifndef KLPQ_H
+#define KLPQ_H
 
-#include <qapplication.h>
-#include <qwidget.h>
-#include <qstring.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qframe.h>
-#include <qlabel.h>
-#include <qlistbox.h>
-#include <qpushbutton.h>
-#include <qlayout.h>
-#include <qtimer.h>
-#include <qaccel.h>
-
-#include <kapp.h>
-#include <kio/job.h>
-#include <ktmainwindow.h>
+#include <kmainwindow.h>
+#include <kurl.h>
 
 #include "ConfAutoUpdate.h"
 #include "SpoolerConfig.h"
 
-class KProcess;
-class MyRowTable;
-class Spooler;
-class QStrList;
-class QListView;
+class QCheckBox;
+class QComboBox;
+class QFrame;
+class QLabel;
+class QListBox;
+class QPushButton;
+class QTimer;
+class QAccel;
+class QStringList;
 class QPopupMenu;
 class QDragEnterEvent;
 class QDropEvent;
 
-#define KLPQ_VERSION "1.01"
+class KListView;
+class KProcess;
 
-class Klpq : public KTMainWindow
+class MyRowTable;
+class Spooler;
+
+class Klpq : public KMainWindow
 {
-  Q_OBJECT;
+  Q_OBJECT
 public:
   Klpq(const char* name=NULL);
   ~Klpq();
@@ -65,7 +59,8 @@ public:
   void addPrintQueue( QString name ) { cb_printer->insertItem(name); }
   void setLastPrinterCurrent();
   void callUpdate() { update(); }
-  void printRemote( QStrList file_list );
+  static bool printURL(const KURL &url, const QString &printer = QString::null);
+  static void messageNotFound();
 
 protected slots:
   void update();
@@ -83,7 +78,6 @@ protected slots:
   void exitedLpq(KProcess *) { lpq_running = FALSE; updateList(); enable(); }
   void recvLpc( KProcess *, char *buffer, int buflen );
   void exitedLpc(KProcess *);
-  void slotIOJobFinished( KIO::Job* );
   void popupMenu();
 
 protected:
@@ -104,7 +98,7 @@ protected:
   QCheckBox   *c_printing;
   QPushButton *b_update;
   QPushButton *b_quit;
-  QListView   *lb_list;
+  KListView   *lb_list;
   QPushButton *b_remove;
   QPushButton *b_make_top;
   QListBox    *lb_status;
@@ -126,10 +120,7 @@ protected:
   SpoolerConfig  *conf_spooler;
   int          update_delay;
 
-  QStrList     remote_files;
-
+  QStringList     remote_files;
 };
 
 #endif /* klpq_included */
-
-
