@@ -23,12 +23,9 @@
 
 #include <stdlib.h>
 
-#include <qstring.h>
 #include <qfile.h>
-#include <qtextstream.h>
 
-#include <kapp.h>
-#include <kdebug.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kcmdlineargs.h>
