@@ -21,12 +21,32 @@
 //  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <kglobal.h>
+#include <klocale.h>
+
 #include "queueview.h"
 
 
-MyLVI::MyLVI(QListView *parent, const QString& ra, const QString& ow, int jo, 
-	     const QString& fi, const QString& si)
-  : QListViewItem(parent, ra, ow, QString().sprintf("%d",jo), fi, si)
+MyLVI::MyLVI(QListView *parent, int _range, const QString& owner,
+	     int _job, const QString& filename, int _filesize)
+  : QListViewItem(parent),
+    range(_range), job(_job), filesize(_filesize)
 {
-  job = jo;
+  setText(0, KGlobal::locale()->formatNumber(range, 0));
+  setText(1, owner);
+  setText(2, KGlobal::locale()->formatNumber(job, 0));
+  setText(3, filename);
+  setText(4, KGlobal::locale()->formatNumber(filesize, 0));
+}
+
+QString MyLVI::key( int column, bool ) const
+{
+  if (column == 0)
+    return QString().sprintf("%10d", range);
+  else if (column == 2)
+    return QString().sprintf("%10d", job);
+  else if (column == 4)
+    return QString().sprintf("%10d", filesize);
+  else
+    return text( column );
 }
