@@ -16,9 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
-#include <kstdaccel.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 
